@@ -3,7 +3,7 @@
 -- 
 --
 
-create table a_fixed ( a int, b fixed(3));
+create table a_decimal ( a int, b decimal(3));
 
 
 drop if exists procedure loadData;
@@ -11,13 +11,13 @@ drop if exists procedure loadData;
 create procedure loadData()
 begin
 
-   delete from a_fixed;
-   insert into a_fixed values ( 1, 1.23);
-   insert into a_fixed values ( 2, 2.345);
-   insert into a_fixed values ( 3, 3.5193);
-   insert into a_fixed values ( 4, 4.111);
-   insert into a_fixed values ( 5, 4.111);
-   insert into a_fixed values ( 6, 4.111);
+   delete from a_decimal;
+   insert into a_decimal values ( 1, 1.23);
+   insert into a_decimal values ( 2, 2.345);
+   insert into a_decimal values ( 3, 3.5193);
+   insert into a_decimal values ( 4, 4.111);
+   insert into a_decimal values ( 5, 4.111);
+   insert into a_decimal values ( 6, 4.111);
 end;
 @
 
@@ -30,21 +30,21 @@ begin
    
    var numrow int;
 
-   :numrow = ( select count(*) from a_fixed where b = 1.230 );
+   :numrow = ( select count(*) from a_decimal where b = (decimal)1.230 );
    if :numrow != 1
    then
 	:res = 'ERROR';
 	return :res;
    end;
 
-   :numrow = ( select count(*) from a_fixed where b = (fixed)2.345 );
+   :numrow = ( select count(*) from a_decimal where b = (decimal)2.345 );
    if :numrow != 1
    then
 	:res = 'ERROR';
 	return :res;
    end;
 
-   :numrow = ( select count(*) from a_fixed where b = 4.111 );
+   :numrow = ( select count(*) from a_decimal where b = (decimal)4.111 );
    if :numrow != 3
    then
 	:res = 'ERROR';
@@ -63,7 +63,7 @@ insert into checklog values ('GATE-E', :msg, :r);
 drop procedure loadData;
 drop procedure checkCast001;
 
-drop if exists table a_fixed;
+drop if exists table a_decimal;
 
 
 
