@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2019 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -37,7 +37,7 @@ class CegoAVLIndexCursor {
     
 public:
     
-    CegoAVLIndexCursor(CegoTableManager* pTM, int tabSetId, const Chain& indexName, CegoObject::ObjectType type, CegoAttrCond* pAttrCond, bool ignoreTouched, bool readUncommitted);
+    CegoAVLIndexCursor(CegoTableManager* pTM, unsigned tabSetId, const Chain& indexName, CegoObject::ObjectType type, CegoAttrCond* pAttrCond, bool ignoreTouched, bool readUncommitted);
     ~CegoAVLIndexCursor();
     
     bool getFirst(ListT<CegoField>& fl, CegoDataPointer& dp);
@@ -65,7 +65,7 @@ private:
     CegoBufferPage _currentPage;
     CegoBufferPage _dataPage;
 
-    int _tabSetId;
+    unsigned _tabSetId;
 
     bool _ignoreTouched;
     bool _readUncommitted;
@@ -76,15 +76,10 @@ private:
     bool _eoc;
     unsigned int _lockId;
     
-    int _cachedLen;
+    unsigned _cachedLen;
     char* _cachedPointer;
 
-    CegoDataType _dt;
     ListT<CegoField> _idxSchema;
 };
 
 #endif
-
-
-
-
