@@ -35,8 +35,6 @@ protected:
    virtual void archLogInfoAction() = 0;
    virtual void logInfoAction() = 0;
    virtual void objInfoAction() = 0;
-   virtual void listNodeAction() = 0;
-   virtual void dbSessionInfoAction() = 0;
    virtual void buFileInfoAction() = 0;
    virtual void buStatInfoAction() = 0;
    virtual void buStatResetAction() = 0;
@@ -47,26 +45,17 @@ protected:
    virtual void dbQueryHistLastAction() = 0;
    virtual void dbQueryHistCostAction() = 0;
    virtual void admThreadInfoAction() = 0;
-   virtual void logThreadInfoAction() = 0;
-   virtual void copyInfoAction() = 0;
    virtual void transactionInfoAction() = 0;
    virtual void abortDbThreadAction() = 0;
-   virtual void retrieveTableSetAction() = 0;
    virtual void defineTableSetAction() = 0;
    virtual void createTableSetAction() = 0;
    virtual void startTableSetAction() = 0;
    virtual void stopTableSetAction() = 0;
-   virtual void copyTableSetAction() = 0;
-   virtual void switchTableSetAction() = 0;
-   virtual void switchSecondaryAction() = 0;
-   virtual void switchMediatorAction() = 0;
-   virtual void relocateSecondaryAction() = 0;
-   virtual void relocateMediatorAction() = 0;
+   virtual void startRecoveryAction() = 0;
+   virtual void stopRecoveryAction() = 0;
    virtual void dropTableSetAction() = 0;
    virtual void removeTableSetAction() = 0;
-   virtual void resetTableSetAction() = 0;
    virtual void addDataFileAction() = 0;
-   virtual void checkTableSetAction() = 0;
    virtual void verifyTableSetAction() = 0;
    virtual void correctTableSetAction() = 0;
    virtual void addUserAction() = 0;
@@ -154,8 +143,6 @@ protected:
    virtual void xmlModeAction() = 0;
    virtual void binModeAction() = 0;
    virtual void plainModeAction() = 0;
-   virtual void storePrimaryAttr() = 0;
-   virtual void storeSecondaryAttr() = 0;
    virtual void storeSysSizeAttr() = 0;
    virtual void storeTmpSizeAttr() = 0;
    virtual void storeLogSizeAttr() = 0;
@@ -166,10 +153,6 @@ protected:
    virtual void storeBranchAttr() = 0;
    virtual void storePit() = 0;
    virtual void storeLsn() = 0;
-   virtual void getDbSpecAction() = 0;
-   virtual void getDbInfoAction() = 0;
-   virtual void setTableSetNodeAction() = 0;
-   virtual void copyFileAction() = 0;
    virtual void dumpTable() = 0;
    virtual void dumpUIndex() = 0;
 
@@ -204,15 +187,13 @@ protected:
       STRUCTURE,
       SORTAREASIZE,
       SIZE,
-      SETTSNODEINFO,
       SET,
       SESSION,
-      SECONDARY,
       ROLE,
       RIGHT,
-      RETRIEVE,
       RESTORE,
       RESET,
+      RECOVERY,
       RECOVER,
       REMOVE,
       RELOCATE,
@@ -220,7 +201,6 @@ protected:
       QUIT,
       QUERYHIST,
       QUERYCACHE,
-      PRIMARY,
       POOL,
       PLAIN,
       PIT,
@@ -276,13 +256,11 @@ protected:
       CPDUMP,
       COST,
       CORRECT,
-      COPY,
       CONNECT,
       CLOSE,
       CLEANUP,
       CLEAN,
       CHECKPOINT,
-      CHECK,
       BY,
       TSTICKET,
       BUSTAT,
@@ -348,8 +326,6 @@ private:
    void loadParser13();
    void loadParser14();
    void loadParser15();
-   void loadParser16();
-   void loadParser17();
 
    class ScannerStateEntry {
 
@@ -446,8 +422,8 @@ class ScannerTransEntry {
       unsigned _num;
    };
 
-   ActionEntry _actionMap[475][128];
-   unsigned _jumpMap[475][20];
+   ActionEntry _actionMap[428][123];
+   unsigned _jumpMap[428][20];
 
    class ProdEntry {
 
