@@ -52,7 +52,6 @@ class CegoAdmNet {
 
     void getDbThreadInfo(ListT<Chain>& dbThreadInfoList);
     void getAdmThreadInfo(ListT<Chain>& admThreadInfoList);
-    void getLogThreadInfo(ListT<Chain>& logThreadInfoList);
 
     void importTableSet(const Chain& tableSet, const Chain& impMode, const Chain& impFile);
     void exportTableSet(const Chain& tableSet, const Chain& expMode, const Chain& expFile);
@@ -61,8 +60,6 @@ class CegoAdmNet {
     
     void defineTableSet(const Chain& tableSet, 
 			const Chain& tsRoot,
-			const Chain& primary,
-			const Chain& secondary,
 			unsigned sysSize,
 			unsigned tmpSize,
 			unsigned appSize,
@@ -74,10 +71,6 @@ class CegoAdmNet {
     void createTableSet(const Chain& tableSet);
     void dropTableSet(const Chain& tableSet);
 
-    void switchSecondary(const Chain& tableSet);
-    void switchMediatorAction(const Chain& tableSet);
-    void relocateSecondary(const Chain& tableSet, const Chain& secondary);
-    void relocateMediator(const Chain& tableSet, const Chain& mediator);
 
     void recoverTableSet(const Chain& tableSet, const Chain& pit, unsigned long long targetlsn);
 
@@ -85,7 +78,7 @@ class CegoAdmNet {
 
 private:
 
-    void handleMedResult(CegoAdminHandler::ResultType res);
+    void handleResult(CegoAdminHandler::ResultType res);
     
     Chain _logFile;
     Chain _progName;
