@@ -156,7 +156,6 @@ CegoAdmScreen::ThreadPool::ThreadPool(CegoAdminHandler* pAH, Screen::Panel* pPar
     
     _pDb = new DbPool(pAH, pParent);
     _pAdm = new AdmPool(pAH, pParent);
-    _pLog = new LogPool(pAH, pParent);
 }
 
 Screen::Panel* CegoAdmScreen::ThreadPool::onSelect(unsigned selected)
@@ -165,8 +164,6 @@ Screen::Panel* CegoAdmScreen::ThreadPool::onSelect(unsigned selected)
 	return _pDb;
     else if ( selected == 2 )
 	return _pAdm;
-    else if ( selected == 3 )
-	return _pLog;
     return this;
 }
 
@@ -519,58 +516,6 @@ void CegoAdmScreen::ThreadPool::AdmPool::refresh()
     }
 }
 
-CegoAdmScreen::ThreadPool::LogPool::LogPool(CegoAdminHandler* pAH, Screen::Panel* pParent)
-    : Screen::Grid(pParent)
-{
-    
-    _threadSchema.Insert(Chain("ThreadId") + VALSEPTOKEN + Chain("r10"));
-    _threadSchema.Insert(Chain("NumRequest") + VALSEPTOKEN + Chain("r10"));
-    _threadSchema.Insert(Chain("Load") + VALSEPTOKEN + Chain("r10"));
-    _threadSchema.Insert(Chain("Status") + VALSEPTOKEN + Chain("l10"));
-    
-    ListT<Screen::GridColor> colorMap;
-    setSchema(Chain("Log Pool"), _threadSchema, colorMap, 0);
-    
-    _pAH = pAH;
-}
-
-void CegoAdmScreen::ThreadPool::LogPool::refresh()
-{
-    ListT<ListT<CegoFieldValue> > logthreadinfo;
-    
-    CegoAdminHandler::ResultType res;
-    CegoTableObject oe;
-    Chain format;    
-    
-    res = _pAH->reqLogThreadInfo();
-    if ( res == CegoAdminHandler::ADM_ERROR )
-    {	
-	Chain msg;
-	_pAH->getMsg(msg);
-	setStatus(msg);
-	return;
-    }
-
-    _pAH->getLogThreadInfo(oe, logthreadinfo, format);
-    
-    _threadTable.Empty();
-	
-    ListT<CegoFieldValue> *pFVL = logthreadinfo.First();
-    while ( pFVL )
-    {
-	ListT<Chain> threadRow;
-	
-	CegoFieldValue *pFV = pFVL->First();
-	while ( pFV )
-	{
-	    threadRow.Insert(pFV->valAsChain());
-	    pFV = pFVL->Next();
-	}
-	
-	_threadTable.Insert(threadRow);
-	pFVL = logthreadinfo.Next();
-    }
-}
 
 ////////////////////
 // Tableset Panel //
@@ -621,7 +566,7 @@ Screen::Panel* CegoAdmScreen::TableSet::onKey(unsigned c, unsigned rowNUm)
 void CegoAdmScreen::TableSet::refresh()
 {
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medGetTableSetList(true);
+    res = _pAH->reqGetTableSetList(true);
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -669,8 +614,6 @@ CegoAdmScreen::TableSet::Add::Add(CegoAdminHandler* pAH, Screen::Panel* pParent,
     ListT<Chain> attrList; 
     attrList.Insert( Chain("Name") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN + Chain("TabNetName"));
     attrList.Insert( Chain("Root Path") + ATTRSEPTOKEN + INPUT_TYPE_STRING + ATTRSEPTOKEN + MAXPATHLEN + ATTRSEPTOKEN + Chain("./RootPath"));
-    attrList.Insert( Chain("Primary") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN);
-    attrList.Insert( Chain("Secondary") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN);
     attrList.Insert( Chain("SystemSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + Chain("100"));
     attrList.Insert( Chain("TempSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + Chain("100"));
     attrList.Insert( Chain("AppSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + Chain("500"));
@@ -691,21 +634,17 @@ Screen::Panel* CegoAdmScreen::TableSet::Add::onConfirm(const ListT<Chain>& valLi
 {
     Chain tableSet = valList[0];
     Chain tsRoot = valList[1];
-    Chain primary = valList[2];
-    Chain secondary = valList[3];
-    unsigned sysSize = valList[4].asUnsigned();
-    unsigned tmpSize = valList[5].asUnsigned();
-    unsigned appSize = valList[6].asUnsigned();
-    unsigned logSize = valList[7].asUnsigned();
-    unsigned logNum = valList[8].asUnsigned();
-    unsigned long long sortAreaSize = valList[9].asUnsignedLongLong();
+    unsigned sysSize = valList[2].asUnsigned();
+    unsigned tmpSize = valList[3].asUnsigned();
+    unsigned appSize = valList[4].asUnsigned();
+    unsigned logSize = valList[5].asUnsigned();
+    unsigned logNum = valList[6].asUnsigned();
+    unsigned long long sortAreaSize = valList[7].asUnsignedLongLong();
     unsigned branchId = 0; // still not supported for screen mode
     
     CegoAdminHandler::ResultType res;
-    res = _pAH->medDefineTableSet(tableSet,
+    res = _pAH->reqDefineTableSet(tableSet,
 				  tsRoot,
-				  primary,
-				  secondary,
 				  sysSize,
 				  tmpSize,
 				  appSize,
@@ -816,7 +755,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::onSelect(unsigned selected)
     case 1:
     {
 	CegoAdminHandler::ResultType res;
-	res = _pAH->medStopTableSet(_tableSet);
+	res = _pAH->reqStopTableSet(_tableSet);
 	
 	Chain msg;
 	_pAH->getMsg(msg);
@@ -845,7 +784,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::onSelect(unsigned selected)
 	bool noInit=false;
 	
 	CegoAdminHandler::ResultType res;
-	res = _pAH->medStartTableSet(_tableSet, doCleanup, doForceload, cpDump, noInit);
+	res = _pAH->reqStartTableSet(_tableSet, doCleanup, doForceload, cpDump, noInit);
 	
 	Chain msg;
 	_pAH->getMsg(msg);
@@ -879,7 +818,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::onSelect(unsigned selected)
     case 10:
     {
 	CegoAdminHandler::ResultType res;
-	res = _pAH->medCreateTableSet(_tableSet);
+	res = _pAH->reqCreateTableSet(_tableSet);
 		
 	Chain msg;
 	_pAH->getMsg(msg);
@@ -893,7 +832,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::onSelect(unsigned selected)
     case 11:
     {
 	CegoAdminHandler::ResultType res;
-	res = _pAH->medRemoveTableSet(_tableSet);
+	res = _pAH->reqRemoveTableSet(_tableSet);
 	    
 	Chain msg;
 	_pAH->getMsg(msg);
@@ -943,7 +882,7 @@ void CegoAdmScreen::TableSet::Action::Edit::setup(const Chain& tableSet)
     CegoAdminHandler::ResultType res;
     CegoTableObject oe;	
     
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);	
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);	
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1015,8 +954,6 @@ void CegoAdmScreen::TableSet::Action::Edit::setup(const Chain& tableSet)
     ListT<Chain> attrList; 
     attrList.Insert( Chain("Name") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN + defTableSet);
     attrList.Insert( Chain("Root Path") + ATTRSEPTOKEN + INPUT_TYPE_STRING + ATTRSEPTOKEN + MAXPATHLEN + ATTRSEPTOKEN + rootPath);
-    attrList.Insert( Chain("Primary") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN);
-    attrList.Insert( Chain("Secondary") + ATTRSEPTOKEN + INPUT_TYPE_ID + ATTRSEPTOKEN + MAXNAMELEN + ATTRSEPTOKEN);
     attrList.Insert( Chain("SystemSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + sysSize);
     attrList.Insert( Chain("TempSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + tempSize);
     attrList.Insert( Chain("AppSpace") + ATTRSEPTOKEN + INPUT_TYPE_NUMBER + ATTRSEPTOKEN + MAXSIZELEN + ATTRSEPTOKEN + appSize);
@@ -1031,20 +968,18 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Edit::onConfirm(const ListT<Chai
 {
     Chain tableSet = valList[0];
     Chain tsRoot = valList[1];
-    Chain primary = valList[2];
-    Chain secondary = valList[3];
-    unsigned sysSize = valList[4].asUnsigned();
-    unsigned tmpSize = valList[5].asUnsigned();
-    unsigned appSize = valList[6].asUnsigned();
-    unsigned logSize = valList[7].asUnsigned();
-    unsigned logNum = valList[8].asUnsigned();
-    unsigned long long sortAreaSize = valList[9].asUnsignedLongLong();
+    unsigned sysSize = valList[2].asUnsigned();
+    unsigned tmpSize = valList[3].asUnsigned();
+    unsigned appSize = valList[4].asUnsigned();
+    unsigned logSize = valList[5].asUnsigned();
+    unsigned logNum = valList[6].asUnsigned();
+    unsigned long long sortAreaSize = valList[7].asUnsignedLongLong();
     unsigned branchId = 0;
     
     // to edit tableset in state DEFINED, we just remove the whole tableset and define it new
     
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRemoveTableSet(_tableSet);
+    res = _pAH->reqRemoveTableSet(_tableSet);
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -1053,10 +988,8 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Edit::onConfirm(const ListT<Chai
 	return setError(Chain(ERROR_TITLE), msg);
     }
 
-    res = _pAH->medDefineTableSet(tableSet,
+    res = _pAH->reqDefineTableSet(tableSet,
 				  tsRoot,
-				  primary,
-				  secondary,
 				  sysSize,
 				  tmpSize,
 				  appSize,
@@ -1098,7 +1031,7 @@ void CegoAdmScreen::TableSet::Action::InfoPanel::refresh()
     CegoAdminHandler::ResultType res;
     CegoTableObject oe;	
     
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);	
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);	
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1305,7 +1238,7 @@ ListT< ListT<Chain> > CegoAdmScreen::TableSet::Action::Archlog::getData()
 void CegoAdmScreen::TableSet::Action::Archlog::refresh()
 {
     CegoAdminHandler::ResultType res;
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);	
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);	
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1345,7 +1278,7 @@ void CegoAdmScreen::TableSet::Action::Archlog::refresh()
 	pFVL = tsInfo.Next();
     }
 
-    res = _pAH->medGetArchLogInfo(_tableSet);    
+    res = _pAH->reqGetArchLogInfo(_tableSet);    
     while ( res == CegoAdminHandler::ADM_INFO )
     {
 	res = _pAH->nextInfo();	    
@@ -1410,7 +1343,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Archlog::Add::onConfirm(const Li
     Chain archPath = valList[1];
 
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medAddArchLog(_tableSet, archId, archPath);
+    res = _pAH->reqAddArchLog(_tableSet, archId, archPath);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -1465,11 +1398,11 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Archlog::Conf::onConfirm(const L
     CegoAdminHandler::ResultType res;   
     if ( mode == Chain("1"))
     {
-	res = _pAH->medEnableArchLog(_tableSet);
+	res = _pAH->reqEnableArchLog(_tableSet);
     }
     else
     {
-	res = _pAH->medDisableArchLog(_tableSet);
+	res = _pAH->reqDisableArchLog(_tableSet);
     }
     
     if ( res == CegoAdminHandler::ADM_ERROR )
@@ -1508,7 +1441,7 @@ void CegoAdmScreen::TableSet::Action::Archlog::Delete::setup(const Chain& tableS
 Screen::Panel* CegoAdmScreen::TableSet::Action::Archlog::Delete::onConfirm()
 {
     CegoAdminHandler::ResultType res;   
-    res = _pAH->medRemoveArchLog(_tableSet, _al);
+    res = _pAH->reqRemoveArchLog(_tableSet, _al);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -1580,7 +1513,7 @@ void CegoAdmScreen::TableSet::Action::Backup::refresh()
     
     CegoAdminHandler::ResultType res;
     Chain pit;
-    res = _pAH->medListBackup(_tableSet, pit);
+    res = _pAH->reqListBackup(_tableSet, pit);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -1636,7 +1569,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Add::onConfirm()
     
     Chain buMsg("Backup via CegoAdmScreen");
     
-    res = _pAH->medBeginBackup(_tableSet, buMsg);	
+    res = _pAH->reqBeginBackup(_tableSet, buMsg);	
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
 	Chain msg;
@@ -1644,7 +1577,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Add::onConfirm()
 	return setError(Chain(ERROR_TITLE),  msg);	
     }
 	    
-    res = _pAH->medExecuteBackup(_tableSet, buMsg);
+    res = _pAH->reqExecuteBackup(_tableSet, buMsg);
     
     Chain errLog;
     while ( res == CegoAdminHandler::ADM_INFO )
@@ -1664,7 +1597,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Add::onConfirm()
 	errLog += msg;
 	
 	// try to end backup 
-	res = _pAH->medEndBackup(_tableSet, buMsg, false);
+	res = _pAH->reqEndBackup(_tableSet, buMsg, false);
 	
 	if ( res == CegoAdminHandler::ADM_ERROR )
 	{
@@ -1675,7 +1608,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Add::onConfirm()
 	return setError(Chain(ERROR_TITLE),  errLog);
     }
     
-    res = _pAH->medEndBackup(_tableSet, buMsg, false);
+    res = _pAH->reqEndBackup(_tableSet, buMsg, false);
     
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -1718,7 +1651,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Restore::onConfirm(const
     if ( pit != Chain() )
     {
 	CegoAdminHandler::ResultType res;
-	res = _pAH->medListBackup(_tableSet, pit);
+	res = _pAH->reqListBackup(_tableSet, pit);
 	    
 	if ( res == CegoAdminHandler::ADM_ERROR )
 	{
@@ -1758,7 +1691,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Restore::onConfirm(const
     }
     
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRestore(_tableSet, _buId);
+    res = _pAH->reqRestore(_tableSet, _buId);
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {	
@@ -1776,7 +1709,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Restore::onConfirm(const
     }
 
     // far now, we do not support lsn recovery
-    res = _pAH->medRecover(_tableSet, pit, 0);
+    res = _pAH->reqRecover(_tableSet, pit, 0);
         
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1822,7 +1755,7 @@ void CegoAdmScreen::TableSet::Action::FilePanel::setup(const Chain& tableSet)
     // get root path
 
     CegoAdminHandler::ResultType res;	
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);	
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);	
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1885,7 +1818,7 @@ void CegoAdmScreen::TableSet::Action::FilePanel::refresh()
 	return;
     
     CegoAdminHandler::ResultType res;	
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);	
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);	
     
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -1981,7 +1914,7 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::FilePanel::AddFilePanel::onConfi
     Chain numPages = valList[2];
     
     CegoAdminHandler::ResultType res;    
-    res = _pAH->medAddDataFile(_tableSet, fileType, _rootPath + Chain("/") + dataFile, numPages.asUnsigned());
+    res = _pAH->reqAddDataFile(_tableSet, fileType, _rootPath + Chain("/") + dataFile, numPages.asUnsigned());
     
     Chain msg;
     _pAH->getMsg(msg);
@@ -2093,7 +2026,7 @@ void CegoAdmScreen::TableSet::Action::QueryCache::setup(const Chain& tableSet)
     CegoAdminHandler::ResultType res;
     CegoTableObject oe;
    
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);
    
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -2207,7 +2140,7 @@ void CegoAdmScreen::TableSet::Action::TableCache::setup(const Chain& tableSet)
     CegoAdminHandler::ResultType res;
     CegoTableObject oe;
    
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);
    
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -2322,7 +2255,7 @@ void CegoAdmScreen::TableSet::Action::Parameter::setup(const Chain& tableSet)
     CegoAdminHandler::ResultType res;
     CegoTableObject oe;
    
-    res = _pAH->medGetDetailedTableSetInfo(_tableSet);
+    res = _pAH->reqGetDetailedTSInfo(_tableSet);
    
     while ( res == CegoAdminHandler::ADM_INFO )
     {
@@ -2401,9 +2334,9 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Parameter::onConfirm(const ListT
 
     // setup auto correct
     if ( autoCorrect == Chain(XML_ON_VALUE) )
-	res = _pAH->medEnableAutoCorrect(_tableSet);
+	res = _pAH->reqEnableAutoCorrect(_tableSet);
     else
-	res = _pAH->medDisableAutoCorrect(_tableSet);
+	res = _pAH->reqDisableAutoCorrect(_tableSet);
    
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -2414,9 +2347,9 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Parameter::onConfirm(const ListT
 
     // setup append mode
     if ( appendMode == Chain(XML_ON_VALUE) )
-	res = _pAH->medEnableAppendMode(_tableSet);
+	res = _pAH->reqEnableAppendMode(_tableSet);
     else
-	res = _pAH->medDisableAppendMode(_tableSet);
+	res = _pAH->reqDisableAppendMode(_tableSet);
    
     if ( res == CegoAdminHandler::ADM_ERROR )
     {
@@ -2478,7 +2411,7 @@ void CegoAdmScreen::TableSet::Action::Drop::setup(const Chain& tableSet)
 Screen::Panel* CegoAdmScreen::TableSet::Action::Drop::onConfirm()
 {
     CegoAdminHandler::ResultType res;
-    res = _pAH->medDropTableSet(_tableSet);
+    res = _pAH->reqDropTableSet(_tableSet);
     
     Chain msg;
     _pAH->getMsg(msg);
