@@ -43,7 +43,7 @@ CegoAdminThreadPool::CegoAdminThreadPool() : Thread()
     queueLock.init(LCKMNG_LOCKWAITDELAY);
 }
 
-CegoAdminThreadPool::CegoAdminThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool, CegoLogThreadPool *pLogPool) : Thread()
+CegoAdminThreadPool::CegoAdminThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool) : Thread()
 {
     queueLock.init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
     
@@ -73,7 +73,7 @@ CegoAdminThreadPool::CegoAdminThreadPool(unsigned poolLimit, CegoDatabaseManager
     while ( i < _poolLimit )
     {	
 	_threadState[i] = READY;
-	_threadList[i]= new CegoAdminThread(this, pDBMng, pDbPool, pLogPool);
+	_threadList[i]= new CegoAdminThread(this, pDBMng, pDbPool);
 	_threadId[i]=i;
 	_numRequest[i]=0;
 	_threadLoad[i]=0;
