@@ -29,7 +29,6 @@
 // CEGO INCLUDES
 #include "CegoDatabaseManager.h"
 #include "CegoDbThreadPool.h"
-#include "CegoLogThreadPool.h"
 
 class CegoAdminThread;
 
@@ -40,7 +39,7 @@ public:
     enum ThreadState { READY, BUSY, CONNECTED };
   
     CegoAdminThreadPool();
-    CegoAdminThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool, CegoLogThreadPool *pLogPool);
+    CegoAdminThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbThreadPool *pDbPool);
     ~CegoAdminThreadPool();
 
     unsigned getPoolLimit() const;
