@@ -36,15 +36,15 @@ class CegoAliasObject : public CegoContentObject {
 
     CegoAliasObject();
     CegoAliasObject(const CegoAliasObject& ao);
-    CegoAliasObject(int tabSetId, const Chain& aliasName);
-    CegoAliasObject(int tabSetId, const Chain& aliasName, const Chain& tabName, const ListT<CegoAttrAlias>& aliasList);
+    CegoAliasObject(unsigned tabSetId, const Chain& aliasName);
+    CegoAliasObject(unsigned tabSetId, const Chain& aliasName, const Chain& tabName, const ListT<CegoAttrAlias>& aliasList);
 	
     ~CegoAliasObject();
     
     void setAliasList(const ListT<CegoAttrAlias>& aliasList);   
     const ListT<CegoAttrAlias>& getAliasList();
 
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
 
     void encode(char *buf) const;
     void decode(char *buf);
@@ -56,7 +56,7 @@ class CegoAliasObject : public CegoContentObject {
     bool operator == ( const CegoAliasObject& oe);
     
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
     CegoContentObject* clone(bool isAttrRef = false);
     
     Chain getInfo() const;
