@@ -59,7 +59,7 @@ const CegoBTreeNode::NodeType CegoBTreeNode::getType() const
     return _nt;
 }
 
-void CegoBTreeNode::setPtr(void* p, int len)
+void CegoBTreeNode::setPtr(void* p, unsigned len)
 {
     _pI = p;
     _len = len;
@@ -70,7 +70,7 @@ void* CegoBTreeNode::getPtr()
     return _pI;
 }
 
-int CegoBTreeNode::getLen() const
+unsigned CegoBTreeNode::getLen() const
 {
     return _len;
 }
@@ -99,17 +99,17 @@ void CegoBTreeNode::initNode()
 {
     if ( _pI )
     {
-	(*(int*)(_pI)) = 0;
+	(*(unsigned*)(_pI)) = 0;
 	return;
     }
     throw Exception(EXLOC, Chain("Btree node not set up"));
 }
 
-int CegoBTreeNode::numEntries() const
+unsigned CegoBTreeNode::numEntries() const
 {
     if ( _pI )
     {
-	return (*(int*)(_pI));
+	return (*(unsigned*)(_pI));
     }
     throw Exception(EXLOC, Chain("Btree node not set up"));
 }
@@ -118,7 +118,7 @@ void CegoBTreeNode::incEntries()
 {
     if ( _pI )
     {
-	(*(int*)(_pI))++;
+	(*(unsigned*)(_pI))++;
 	return;
     }
     throw Exception(EXLOC, Chain("Btree node not set up"));
@@ -128,13 +128,13 @@ void CegoBTreeNode::decEntries()
 {
     if ( _pI )
     {
-	(*(int*)(_pI))--;
+	(*(unsigned*)(_pI))--;
 	return;
     }
     throw Exception(EXLOC, Chain("Btree node not set up"));
 }
 
-int CegoBTreeNode::getEntrySize() const
+unsigned CegoBTreeNode::getEntrySize() const
 {
     return _entrySize;
 }
@@ -145,22 +145,22 @@ void CegoBTreeNode::getChildPage(const CegoBTreeValue& iv, PageIdType& pageId, b
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    int ne = numEntries();
+    unsigned ne = numEntries();
 
     if ( ne == 0 )
 	throw Exception(EXLOC, "No child entries avaiable");
 
-    int lb=0;
-    int rb=ne;
+    unsigned lb=0;
+    unsigned rb=ne;
 
-    int i;
+    unsigned i;
     bool posFound=false;
     
     while ( posFound == false)
     {
 	i = (lb+rb) / 2;
 
-	char* pKey = (char*)((long long)_pI + sizeof(int)) + sizeof(PageIdType) + i * getEntrySize();
+	char* pKey = (char*)((long long)_pI + sizeof(unsigned)) + sizeof(PageIdType) + i * getEntrySize();
 	CegoBTreeValue nv;
 	nv.setPtr(pKey, _keyLen);
 
@@ -187,7 +187,7 @@ void CegoBTreeNode::getChildPage(const CegoBTreeValue& iv, PageIdType& pageId, b
 	    {
 		// cout << "Checking left value .." << endl;
 		// we still have to check the left value
-		char* pLeftKey = (char*)((long long)_pI + sizeof(int)) + sizeof(PageIdType) + lb * getEntrySize();
+		char* pLeftKey = (char*)((long long)_pI + sizeof(unsigned)) + sizeof(PageIdType) + lb * getEntrySize();
 		CegoBTreeValue lv;
 		lv.setPtr(pLeftKey, _keyLen);
 		
@@ -209,13 +209,13 @@ void CegoBTreeNode::getChildPage(const CegoBTreeValue& iv, PageIdType& pageId, b
 	}      
     }
 
-    char* p = (char*)((long long)_pI + sizeof(int)) + i * getEntrySize();
+    char* p = (char*)((long long)_pI + sizeof(unsigned)) + i * getEntrySize();
 
     memcpy(&pageId, p, sizeof(PageIdType));    
     return;
 }
 
-void CegoBTreeNode::setSchema(NodeType nt, ListT<CegoField>* pSchema, int keyLen)
+void CegoBTreeNode::setSchema(NodeType nt, ListT<CegoField>* pSchema, unsigned keyLen)
 {
     _pSchema = pSchema;
     _keyLen = keyLen;
@@ -223,12 +223,12 @@ void CegoBTreeNode::setSchema(NodeType nt, ListT<CegoField>* pSchema, int keyLen
 
     if ( _nt == LEAF )
     {
-	_maxEntries = ( _len - sizeof(int) )  / ( _keyLen + DPENCODINGLENGTH );
+	_maxEntries = ( _len - sizeof(unsigned) )  / ( _keyLen + DPENCODINGLENGTH );
 	_entrySize = _keyLen + DPENCODINGLENGTH;
     }
     else if ( _nt == NODE )
     {	
-	_maxEntries = ( _len - sizeof(int) - sizeof(PageIdType) ) / ( _keyLen + sizeof(PageIdType) );
+	_maxEntries = ( _len - sizeof(unsigned) - sizeof(PageIdType) ) / ( _keyLen + sizeof(PageIdType) );
 	_entrySize = _keyLen + sizeof(PageIdType);
     }
     else
@@ -237,22 +237,22 @@ void CegoBTreeNode::setSchema(NodeType nt, ListT<CegoField>* pSchema, int keyLen
     }
 }
 
-bool CegoBTreeNode::valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM, int tabSetId, unsigned long long tid) const
+bool CegoBTreeNode::valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM, unsigned tabSetId, unsigned long long tid) const
 {    
     if ( _nt == NODE )
       throw Exception(EXLOC, Chain("Invalid method for node type"));
     
-    int ne = numEntries();
+    unsigned ne = numEntries();
     
     if ( ne == 0 )
     {
 	return false;
     }
         
-    int lb=0;
-    int rb=ne;
+    unsigned lb=0;
+    unsigned rb=ne;
 
-    int i = (lb+rb) / 2;
+    unsigned i = (lb+rb) / 2;
     
     bool posFound=false;
 
@@ -269,8 +269,8 @@ bool CegoBTreeNode::valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM
 	CegoBTreeValue nv;
 	CegoDataPointer dp;
 
-	nv.setPtr((char*)((long long)_pI + sizeof(int)) + i * getEntrySize(), _keyLen);
-	dp.decode((char*)((long long)_pI + sizeof(int)) + i * getEntrySize() + _keyLen);
+	nv.setPtr((char*)((long long)_pI + sizeof(unsigned)) + i * getEntrySize(), _keyLen);
+	dp.decode((char*)((long long)_pI + sizeof(unsigned)) + i * getEntrySize() + _keyLen);
 	
 	CegoBTreeValue::Comparison valueComp = iv.comp(nv, _pSchema);
 	
@@ -318,8 +318,8 @@ bool CegoBTreeNode::valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM
 		while ( d >= 0 && goOn )
 		{
 		    // cout << "Searching down " << d << endl;
-		    nv.setPtr((char*)((long long)_pI + sizeof(int)) + (d)*getEntrySize(), _keyLen);
-		    dp.decode((char*)((long long)_pI + sizeof(int)) + (d)*getEntrySize() + _keyLen);
+		    nv.setPtr((char*)((long long)_pI + sizeof(unsigned)) + (d)*getEntrySize(), _keyLen);
+		    dp.decode((char*)((long long)_pI + sizeof(unsigned)) + (d)*getEntrySize() + _keyLen);
 
 		    CegoBTreeValue::Comparison downComp = iv.comp(nv, _pSchema);
 
@@ -340,13 +340,13 @@ bool CegoBTreeNode::valueExists(const CegoBTreeValue& iv, CegoObjectManager *pOM
 
 		// search up
 		
-		int u = i+1;
+		unsigned u = i+1;
 		goOn = true;
 		while ( u < ne && goOn )
 		{
 		    // cout << "Searching up " << u << endl;
-		    nv.setPtr((char*)((long long)_pI + sizeof(int)) + (u)*getEntrySize(), _keyLen);
-		    dp.decode((char*)((long long)_pI + sizeof(int)) + (u)*getEntrySize() + _keyLen);
+		    nv.setPtr((char*)((long long)_pI + sizeof(unsigned)) + (u)*getEntrySize(), _keyLen);
+		    dp.decode((char*)((long long)_pI + sizeof(unsigned)) + (u)*getEntrySize() + _keyLen);
 
 		    CegoBTreeValue::Comparison upComp = iv.comp(nv, _pSchema);
 
@@ -376,7 +376,7 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
     if ( _nt == NODE )
       throw Exception(EXLOC, Chain("Invalid method for node type"));
     
-    int ne = numEntries();
+    unsigned ne = numEntries();
     
     if ( ne == _maxEntries )
     {
@@ -385,7 +385,7 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
 
     if ( ne == 0 )
     {
-	char* pKey = (char*)((long long)_pI + sizeof(int));
+	char* pKey = (char*)((long long)_pI + sizeof(unsigned));
 	memcpy(pKey, iv.getPtr(), _keyLen);
 	char* pDP = (char*)((long long)pKey + _keyLen);
 	dp.encode(pDP);
@@ -395,10 +395,10 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
 	return true;	
     }
         
-    int lb=0;
-    int rb=ne;
+    unsigned lb=0;
+    unsigned rb=ne;
 
-    int i = (lb+rb) / 2;
+    unsigned i = (lb+rb) / 2;
     
     bool posFound=false;
 
@@ -412,8 +412,8 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
 	CegoDataPointer dp1;
 	CegoDataPointer dp2;
 
-	nv1.setPtr((char*)((long long)_pI + sizeof(int)) + i * getEntrySize(), _keyLen);
-	dp1.decode((char*)((long long)_pI + sizeof(int)) + i * getEntrySize() + _keyLen);
+	nv1.setPtr((char*)((long long)_pI + sizeof(unsigned)) + i * getEntrySize(), _keyLen);
+	dp1.decode((char*)((long long)_pI + sizeof(unsigned)) + i * getEntrySize() + _keyLen);
 
 	CegoBTreeValue::Comparison valueComp1 = iv.comp(nv1, _pSchema);
 	CegoBTreeValue::Comparison valueComp2;
@@ -424,8 +424,8 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
 	}
 	else
 	{
-	    nv2.setPtr((char*)((long long)_pI + sizeof(int)) + (i+1)*getEntrySize(), _keyLen);
-	    dp2.decode((char*)((long long)_pI + sizeof(int)) + (i+1)*getEntrySize() + _keyLen);
+	    nv2.setPtr((char*)((long long)_pI + sizeof(unsigned)) + (i+1)*getEntrySize(), _keyLen);
+	    dp2.decode((char*)((long long)_pI + sizeof(unsigned)) + (i+1)*getEntrySize() + _keyLen);
 
 	    valueComp2 = iv.comp(nv2, _pSchema);
 	}
@@ -457,7 +457,7 @@ bool CegoBTreeNode::addValue(const CegoBTreeValue& iv, const CegoDataPointer& dp
 	shiftEntries(i, 1);
     }
 
-    char* pKey = (char*)((long long)_pI + sizeof(int) + i* getEntrySize());    
+    char* pKey = (char*)((long long)_pI + sizeof(unsigned) + i* getEntrySize());    
     memcpy(pKey, iv.getPtr(), _keyLen);
     char* pDP = (char*)((long long)pKey + _keyLen);
     dp.encode(pDP);
@@ -472,16 +472,16 @@ bool CegoBTreeNode::deleteValue(const CegoBTreeValue& iv, const CegoDataPointer&
     if ( _nt == NODE )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    int ne = numEntries();
+    unsigned ne = numEntries();
 
     if ( ne == 0 )
 	return false;
 
-    char* pKey = (char*)((long long)_pI + sizeof(int));
+    char* pKey = (char*)((long long)_pI + sizeof(unsigned));
 
     CegoBTreeValue lv;
     
-    int i=0;
+    unsigned i=0;
     while ( i < ne )
     {
 	lv.setPtr(pKey, _keyLen);
@@ -508,7 +508,7 @@ bool CegoBTreeNode::addNode(const CegoBTreeValue& iv, const CegoBTreeNode& node)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
     
-    int ne = numEntries();       	
+    unsigned ne = numEntries();       	
     if ( ne == _maxEntries || ne == 0 )
     {
 	return false;
@@ -516,11 +516,11 @@ bool CegoBTreeNode::addNode(const CegoBTreeValue& iv, const CegoBTreeNode& node)
 
     bool posFound=false;
     char* p = 0;
-    int i=0;	    
+    unsigned i=0;	    
     
     while ( i < ne && posFound == false)
     {	
-	p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+	p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
 	CegoBTreeValue nv(p, _keyLen);
 	if ( nv.isHigher(iv, _pSchema) )
 	{
@@ -550,7 +550,7 @@ bool CegoBTreeNode::addNode(const CegoBTreeValue& iv, const CegoBTreeNode& node)
     // Setting up new node information //
     ////////////////////////////////////
 
-    p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+    p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
     
     // put index value
     memcpy(p, iv.getPtr(), _keyLen);
@@ -568,23 +568,23 @@ bool CegoBTreeNode::addNode(const CegoBTreeValue& iv, const CegoBTreeNode& node)
 
 void CegoBTreeNode::split(CegoBTreeNode& n)
 {
-    int pos = 0; 
+    unsigned pos = 0; 
 
     if ( _nt == LEAF )
     {
 	pos = numEntries() / 2;
-	char* srcPtr = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
-	char* destPtr = (char*)((long long)n._pI + sizeof(int));
-	int s =  ( numEntries() - pos ) * getEntrySize();
+	char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
+	char* destPtr = (char*)((long long)n._pI + sizeof(unsigned));
+	unsigned s =  ( numEntries() - pos ) * getEntrySize();
 
 	memcpy(destPtr, srcPtr, s);	
     }
     else if ( _nt == NODE )
     {
 	pos = numEntries() / 2;
-	char* srcPtr = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
-	char* destPtr = (char*)((long long)n._pI + sizeof(int));
-	int s =  ( numEntries() - pos ) * getEntrySize() + sizeof(PageIdType);
+	char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
+	char* destPtr = (char*)((long long)n._pI + sizeof(unsigned));
+	unsigned s =  ( numEntries() - pos ) * getEntrySize() + sizeof(PageIdType);
 
 	memcpy(destPtr, srcPtr, s);	
     }
@@ -593,27 +593,28 @@ void CegoBTreeNode::split(CegoBTreeNode& n)
 	throw Exception(EXLOC, Chain("Invalid method for undefined node type"));
     }
 
-    int s1 = pos;
-    int s2 = numEntries() - pos;
-    memcpy(_pI, &s1, sizeof(int));
-    memcpy(n._pI, &s2, sizeof(int));
+    unsigned s1 = pos;
+    unsigned s2 = numEntries() - pos;
+    memcpy(_pI, &s1, sizeof(unsigned));
+    memcpy(n._pI, &s2, sizeof(unsigned));
 }
 
-void CegoBTreeNode::shiftEntries(int pos, int offset)
+// Note : offset might be < 0
+void CegoBTreeNode::shiftEntries(unsigned pos, int offset)
 {
     if ( _nt == LEAF )
     {
-	char* srcPtr = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
-	char* destPtr = (char*)((long long)_pI + sizeof(int) + ( pos + offset) * getEntrySize());
-	int shiftSize = ( numEntries() - pos ) * getEntrySize();
+	char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
+	char* destPtr = (char*)((long long)_pI + sizeof(unsigned) + ( pos + offset) * getEntrySize());
+	unsigned shiftSize = ( numEntries() - pos ) * getEntrySize();
 
 	memmove(destPtr, srcPtr, shiftSize);
     }
     else if ( _nt == NODE )
     {
-	char* srcPtr = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + pos * getEntrySize());
-	char* destPtr = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + ( pos + offset ) * getEntrySize());
-	int shiftSize = ( numEntries() - pos ) * getEntrySize();
+	char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + pos * getEntrySize());
+	char* destPtr = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + ( pos + offset ) * getEntrySize());
+	unsigned shiftSize = ( numEntries() - pos ) * getEntrySize();
 
 	memmove(destPtr, srcPtr, shiftSize);
     }
@@ -626,13 +627,13 @@ CegoBTreeValue CegoBTreeNode::getMin() const
           
     if ( _nt == LEAF )    
     {
-	char* p = (char*)((long long)_pI + sizeof(int));
+	char* p = (char*)((long long)_pI + sizeof(unsigned));
 	CegoBTreeValue iv(p, _keyLen);
 	return iv;
     }
     else if ( _nt == NODE )
     {
-	char* p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType));
+	char* p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType));
 	CegoBTreeValue iv(p, _keyLen);
 	return iv;
     }
@@ -644,18 +645,18 @@ CegoBTreeValue CegoBTreeNode::getMin() const
 
 CegoBTreeValue CegoBTreeNode::getMax() const
 {
-    int pos = numEntries() - 1;
+    unsigned pos = numEntries() - 1;
 
     if ( pos >= 0 )
     {
 	char* p;
 	if ( _nt == LEAF )
 	{
-	    p = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
+	    p = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
 	}
 	else
 	{
-	    p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + pos * getEntrySize());
+	    p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + pos * getEntrySize());
 	}
 	CegoBTreeValue iv(p, _keyLen);
 	return iv;
@@ -669,7 +670,7 @@ bool CegoBTreeNode::propagate(const CegoBTreeValue& iv, const CegoBTreeNode& lef
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
  
-    int ne = numEntries();       	
+    unsigned ne = numEntries();       	
     if ( ne == _maxEntries )
     {
 	return false;
@@ -679,7 +680,7 @@ bool CegoBTreeNode::propagate(const CegoBTreeValue& iv, const CegoBTreeNode& lef
     {
 	// first entry
 	
-	char* p = (char*)((long long)_pI + sizeof(int));
+	char* p = (char*)((long long)_pI + sizeof(unsigned));
 	PageIdType pageId, nextPageId;
 	
 	// put left child pointer
@@ -705,11 +706,11 @@ bool CegoBTreeNode::propagate(const CegoBTreeValue& iv, const CegoBTreeNode& lef
     {
 	bool posFound=false;
 	char* p = 0;
-	int i=0;	    
+	unsigned i=0;	    
 
 	while ( i < ne && posFound == false)
 	{
-	    p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+	    p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
 	    CegoBTreeValue nv(p, _keyLen);
 
 	    // cout << "Comparing " << iv.toChain(_pSchema) << " and " << nv.toChain(_pSchema) << "i=" << i << "ne=" << ne << endl;
@@ -742,7 +743,7 @@ bool CegoBTreeNode::propagate(const CegoBTreeValue& iv, const CegoBTreeNode& lef
 	// Setting up new node information //
 	////////////////////////////////////
 
-	p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+	p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
 	
 	// put index value
 	memcpy(p, iv.getPtr(), _keyLen);
@@ -775,14 +776,14 @@ CegoBTreeNode& CegoBTreeNode::operator = (const CegoBTreeNode& n)
 
 bool CegoBTreeNode::verify()
 {
-    int n = numEntries();
+    unsigned n = numEntries();
 
     if ( _nt == LEAF )
     {
-	int i = 0;
+        unsigned i = 0;
 	while ( i < n )
 	{	    
-	    char* srcPtr = (char*)((long long)_pI + sizeof(int) + i * getEntrySize());
+	    char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + i * getEntrySize());
 	    CegoBTreeValue iv;
 	    iv.setPtr(srcPtr, _keyLen);
 	    srcPtr += _keyLen;
@@ -802,7 +803,7 @@ bool CegoBTreeNode::verify()
     {
 	PageIdType pageId;
 
-	char* p = (char*)((long long)_pI + sizeof(int));
+	char* p = (char*)((long long)_pI + sizeof(unsigned));
 	
 	memcpy(&pageId, p, sizeof(PageIdType));
 			  
@@ -814,12 +815,12 @@ bool CegoBTreeNode::verify()
 	    return false;
 	}
 	
-	int i = 0;
+	unsigned i = 0;
 	while ( i < n )
 	{
 	    // cout << levelIndent(level) << "Key " << i << " : ";
 	    
-	    p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+	    p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
 	    CegoBTreeValue iv;
 	    iv.setPtr(p, _keyLen);
 	    // cout << iv.toChain(_pSchema) << endl;
@@ -847,16 +848,16 @@ bool CegoBTreeNode::verify()
     return true;
 }
 
-bool CegoBTreeNode::verifyLeafFull(int tabSetId, CegoObjectManager *pOM)
+bool CegoBTreeNode::verifyLeafFull(unsigned tabSetId, CegoObjectManager *pOM)
 {
-    int n = numEntries();
+    unsigned n = numEntries();
     
     if ( _nt == LEAF )
     {
-	int i = 0;
+	unsigned i = 0;
 	while ( i < n )
 	{	    
-	    char* srcPtr = (char*)((long long)_pI + sizeof(int) + i * getEntrySize());
+	    char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + i * getEntrySize());
 	    CegoBTreeValue iv;
 	    iv.setPtr(srcPtr, _keyLen);
 	    
@@ -872,7 +873,7 @@ bool CegoBTreeNode::verifyLeafFull(int tabSetId, CegoObjectManager *pOM)
 	    else
 	    {		
 		char* p;
-		int len;
+		unsigned len;
 
 		CegoBufferPage bp;
 		pOM->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, bp);
@@ -884,10 +885,10 @@ bool CegoBTreeNode::verifyLeafFull(int tabSetId, CegoObjectManager *pOM)
 		CegoTupleState ts;
 
 		CegoQueryHelper qh;
-		int toff = qh.decodeTupleHeader(tid, tastep, ts, p);
+		unsigned toff = qh.decodeTupleHeader(tid, tastep, ts, p);
 		
 		char* tp = p + toff;
-		int tlen = len - toff;
+		unsigned tlen = len - toff;
 
 		ListT<CegoField> fl = *_pSchema;
 		qh.decodeFVL(fl, tp, tlen);
@@ -925,21 +926,21 @@ bool CegoBTreeNode::verifyLeafFull(int tabSetId, CegoObjectManager *pOM)
     }
 }
 
-void CegoBTreeNode::printNode(int level)
+void CegoBTreeNode::printNode(unsigned level)
 {
-    int n = numEntries();
+    unsigned n = numEntries();
 
     if ( _nt == LEAF )
     {
 	cout << levelIndent(level) << "------- LEAF -------" << endl;
 	cout << levelIndent(level) << "NumEntries=" << n << " PageId=" << _pageId << endl;
 
-	int i = 0;
+	unsigned i = 0;
 	while ( i < n )
 	{
 	    cout << levelIndent(level) << "Entry " << i << " : ";
 	    
-	    char* srcPtr = (char*)((long long)_pI + sizeof(int) + i * getEntrySize());
+	    char* srcPtr = (char*)((long long)_pI + sizeof(unsigned) + i * getEntrySize());
 	    CegoBTreeValue iv;
 	    iv.setPtr(srcPtr, _keyLen);
 	    srcPtr += _keyLen;
@@ -958,18 +959,18 @@ void CegoBTreeNode::printNode(int level)
 
 	PageIdType pageId;
 
-	char* p = (char*)((long long)_pI + sizeof(int));
+	char* p = (char*)((long long)_pI + sizeof(unsigned));
 	
 	memcpy(&pageId, p, sizeof(PageIdType));
 			  
 	cout << levelIndent(level) << "Child : " << pageId << endl;
 
-	int i = 0;
+	unsigned i = 0;
 	while ( i < n )
 	{
 	    cout << levelIndent(level) << "Key " << i << " : ";
 	    
-	    p = (char*)((long long)_pI + sizeof(int) + sizeof(PageIdType) + i * getEntrySize());
+	    p = (char*)((long long)_pI + sizeof(unsigned) + sizeof(PageIdType) + i * getEntrySize());
 	    CegoBTreeValue iv;
 	    iv.setPtr(p, _keyLen);
 	    cout << iv.toChain(_pSchema) << endl;
@@ -991,12 +992,12 @@ void CegoBTreeNode::printNode(int level)
 
 void CegoBTreeNode::reset()
 {
-    _pNextChild = (char*)((long long)_pI + sizeof(int));
+    _pNextChild = (char*)((long long)_pI + sizeof(unsigned));
 }
 
-void CegoBTreeNode::setPosition(int pos)
+void CegoBTreeNode::setPosition(unsigned pos)
 {
-    _pNextChild = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
+    _pNextChild = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
 }
 
 bool CegoBTreeNode::nextChildPointer(PageIdType &pageId)
@@ -1004,7 +1005,7 @@ bool CegoBTreeNode::nextChildPointer(PageIdType &pageId)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()) )
+    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(unsigned) + numEntries() * getEntrySize()) )
 	return false;
     
     memcpy(&pageId, _pNextChild, sizeof(PageIdType));
@@ -1015,26 +1016,26 @@ bool CegoBTreeNode::nextChildPointer(PageIdType &pageId)
     return true;
 }
 
-int CegoBTreeNode::getMedPage(int lb, int rb, PageIdType& pageId)
+unsigned CegoBTreeNode::getMedPage(unsigned lb, unsigned rb, PageIdType& pageId)
 {
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
     
-    int med = (lb + rb) / 2;
-    char* _pMed = (char*)((long long)_pI + (long long)(sizeof(int) + med * getEntrySize()));
+    unsigned med = (lb + rb) / 2;
+    char* _pMed = (char*)((long long)_pI + (long long)(sizeof(unsigned) + med * getEntrySize()));
     
     memcpy(&pageId, _pMed, sizeof(PageIdType));
    
     return med;
 }
 
-bool CegoBTreeNode::rightValue(int pos, CegoBTreeValue& val)
+bool CegoBTreeNode::rightValue(unsigned pos, CegoBTreeValue& val)
 {
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    char* pChild = (char*)((long long)_pI + sizeof(int) + pos * getEntrySize());
-    if ( (long long)pChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
+    char* pChild = (char*)((long long)_pI + sizeof(unsigned) + pos * getEntrySize());
+    if ( (long long)pChild > (long long)_pI + (long long)(sizeof(unsigned) + numEntries() * getEntrySize()))
 	return false;
         
     pChild+=sizeof(PageIdType);
@@ -1054,7 +1055,7 @@ void CegoBTreeNode::getLastChildPointer(PageIdType &pageId) const
     }
     else
     {
-	char *p = (char*)((long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()));    
+	char *p = (char*)((long long)_pI + (long long)(sizeof(unsigned) + numEntries() * getEntrySize()));    
 	memcpy(&pageId, p, sizeof(PageIdType));
     }
 }
@@ -1064,7 +1065,7 @@ void CegoBTreeNode::setFirstChildPointer(PageIdType pageId)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    char *p = (char*)((long long)_pI + (long long)sizeof(int));    
+    char *p = (char*)((long long)_pI + (long long)sizeof(unsigned));    
     memcpy(p, &pageId, sizeof(PageIdType));
 }
 
@@ -1073,14 +1074,14 @@ bool CegoBTreeNode::rightChild(CegoBTreeValue& val)
     if ( _nt == LEAF )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
    
-    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
+    if ( (long long)_pNextChild > (long long)_pI + (long long)(sizeof(unsigned) + numEntries() * getEntrySize()))
 	return false;
     
     val.setPtr(_pNextChild - _keyLen, _keyLen);
     return true;
 }
 
-void CegoBTreeNode::getValue(int pos, CegoBTreeValue& val, CegoDataPointer& dp)
+void CegoBTreeNode::getValue(unsigned pos, CegoBTreeValue& val, CegoDataPointer& dp)
 {
     if ( _nt == NODE )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
@@ -1088,7 +1089,7 @@ void CegoBTreeNode::getValue(int pos, CegoBTreeValue& val, CegoDataPointer& dp)
     if ( pos >= numEntries() )
 	throw Exception(EXLOC, Chain("Node position out of range"));
 
-    char* pVal = (char*)((long long)_pI + (long long)(sizeof(int) + pos * getEntrySize()));
+    char* pVal = (char*)((long long)_pI + (long long)(sizeof(unsigned) + pos * getEntrySize()));
     
     val.setPtr(pVal, _keyLen);
     pVal +=_keyLen;
@@ -1100,7 +1101,7 @@ bool CegoBTreeNode::nextValue(CegoBTreeValue& val, CegoDataPointer& dp)
     if ( _nt == NODE )
 	throw Exception(EXLOC, Chain("Invalid method for node type"));
 
-    if ( (long long)_pNextChild >= (long long)_pI + (long long)(sizeof(int) + numEntries() * getEntrySize()))
+    if ( (long long)_pNextChild >= (long long)_pI + (long long)(sizeof(unsigned) + numEntries() * getEntrySize()))
 	return false;
     
     val.setPtr(_pNextChild, _keyLen);
@@ -1112,7 +1113,7 @@ bool CegoBTreeNode::nextValue(CegoBTreeValue& val, CegoDataPointer& dp)
 }
 
 
-Chain CegoBTreeNode::levelIndent(int level)
+Chain CegoBTreeNode::levelIndent(unsigned level)
 {
     Chain s;
     while ( level > 0 )
@@ -1123,10 +1124,10 @@ Chain CegoBTreeNode::levelIndent(int level)
     return s;
 }
 
-bool CegoBTreeNode::isTupleVisible(CegoObjectManager* pOM, const CegoDataPointer &dp, int tabSetId, unsigned long long tid) const
+bool CegoBTreeNode::isTupleVisible(CegoObjectManager* pOM, const CegoDataPointer &dp, unsigned tabSetId, unsigned long long tid) const
 {    
     char* p;
-    int len;
+    unsigned len;
 
     CegoBufferPage bp;
     pOM->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, bp);
