@@ -31,7 +31,7 @@ public:
     CegoCheckpoint();
     ~CegoCheckpoint();
 
-    bool checkpointReached(const Chain& tableSet, int interval);
+    bool checkpointReached(const Chain& tableSet, unsigned interval);
 
  private:
 
