@@ -380,13 +380,8 @@ int main(int argc, char **argv)
 
     Chain homeDir(getenv(HOMEVAR));
     
-#ifdef HAVE_MINGW
-    histPath = homeDir + "\\" + Chain(HISTFILE);
-    pgHistPath = homeDir + "\\" + Chain(PGHISTFILE);
-#else
     histPath = homeDir + "/" + Chain(HISTFILE);
     pgHistPath = homeDir + "/" + Chain(PGHISTFILE);
-#endif
 
     if ( longOpt.isSet( Chain("version") ) )
     {
