@@ -65,29 +65,6 @@
 #define SER_GETCLOB "clg"
 #define SER_DELCLOB "cld"
 
-// distributed requests
-#define SER_CREATETABLE "createtable"
-#define SER_CREATEVIEW "creatview"
-#define SER_CREATEPROCEDURE "createproc"
-#define SER_CREATECHECK "createcheck"
-#define SER_ALTERTABLE "altertable"
-#define SER_CREATEINDEX "createindex"
-#define SER_INSERT "insert"
-#define SER_DELETE "delete"
-#define SER_UPDATE "update"
-#define SER_OBJECTINFO "objinfo"
-#define SER_DROP_OBJECT "dropobj"
-#define SER_GETTABLE "gettable"
-#define SER_GETOBJLIST "getoblist"
-#define SER_GETOBJLISTBYTABLE "getobjlistbytable"
-#define SER_OBJRENAME "objrename"
-#define SER_REORG "reorg"
-#define SER_SYNC "sync"
-#define SER_GETPAGECOUNT "getpgcount"
-#define SER_STARTTRANSACTION "stta"
-#define SER_COMMITTRANSACTION "ctta"
-#define SER_ROLLBACKTRANSACTION "rbta"
-#define SER_GETTID "gettid"
 #define SER_SESSION_CLOSE "sesclose"
 
 CegoDbHandler::CegoDbHandler(NetHandler *pN, CegoDbHandler::ProtocolType pt, CegoModule *pModule)
@@ -2035,82 +2012,6 @@ CegoDbHandler::RequestType CegoDbHandler::acceptRequest()
 	{
 	    return CegoDbHandler::QUERYABORT;
 	}
-	else if ( docType == Chain(XML_DBPRODINFO_REQUEST) ) 
-	{
-	    return CegoDbHandler::DBPRODINFO;
-	}
-	else if (  docType == Chain(XML_CREATETABLE_REQUEST) ) 
-	{
-	    return CegoDbHandler::CREATETABLE;
-	}
-	else if (  docType == Chain(XML_CREATEVIEW_REQUEST) ) 
-	{
-	    return CegoDbHandler::CREATEVIEW;
-	}
-	else if (  docType == Chain(XML_CREATEPROCEDURE_REQUEST) ) 
-	{
-	    return CegoDbHandler::CREATEPROCEDURE;
-	}
-	else if (  docType == Chain(XML_CREATECHECK_REQUEST) ) 
-	{
-	    return CegoDbHandler::CREATECHECK;
-	}
-	else if (  docType == Chain(XML_ALTERTABLE_REQUEST) ) 
-	{
-	    return CegoDbHandler::ALTERTABLE;
-	}
-	else if (  docType == Chain(XML_CREATEINDEX_REQUEST) ) 
-	{
-	    return CegoDbHandler::CREATEINDEX;
-	}
-	else if (  docType == Chain(XML_INSERT_REQUEST) ) 
-	{
-	    return CegoDbHandler::INSERT;
-	}
-	else if (  docType == Chain(XML_DELETE_REQUEST) ) 
-	{
-	    return CegoDbHandler::DELETETABLE;
-	}
-	else if (  docType == Chain(XML_UPDATE_REQUEST) ) 
-	{
-	    return CegoDbHandler::UPDATE;
-	}
-	else if (  docType == Chain(XML_OBJECTINFO_REQUEST) ) 
-	{
-	    return CegoDbHandler::OBJECTINFO;
-	}
-	else if (  docType == Chain(XML_DROP_OBJECT_REQUEST) ) 
-	{
-	    return CegoDbHandler::DROPOBJECT;
-	}
-	else if (  docType == Chain(XML_GETTABLE_REQUEST) ) 
-	{
-	    return CegoDbHandler::GETTABLE;
-	}
-	else if (  docType == Chain(XML_GETOBJLIST_REQUEST) ) 
-	{
-	    return CegoDbHandler::GETOBJLIST;
-	}
-	else if (  docType == Chain(XML_GETOBJLISTBYTABLE_REQUEST) ) 
-	{
-	    return CegoDbHandler::GETOBJLISTBYTABLE;
-	}
-	else if (  docType == Chain(XML_OBJRENAME_REQUEST) ) 
-	{
-	    return CegoDbHandler::OBJRENAME;
-	}
-	else if (  docType == Chain(XML_REORG_REQUEST) ) 
-	{
-	    return CegoDbHandler::REORGOBJ;
-	}
-	else if (  docType == Chain(XML_SYNC_REQUEST) ) 
-	{
-	    return CegoDbHandler::SYNC;
-	}
-	else if (  docType == Chain(XML_GETPAGECOUNT_REQUEST) ) 
-	{
-	    return CegoDbHandler::GETPAGECOUNT;
-	}
 	else if (  docType == Chain(XML_PUTBLOB_REQUEST) ) 
 	{	    
 	    return CegoDbHandler::PUTBLOB;
@@ -2135,22 +2036,6 @@ CegoDbHandler::RequestType CegoDbHandler::acceptRequest()
 	{
 	    return CegoDbHandler::DELCLOB;
 	}
-	else if (  docType == Chain(XML_STARTTRANSACTION_REQUEST) ) 
-	{
-	    return CegoDbHandler::STARTTRANSACTION;
-	}
-	else if (  docType == Chain(XML_COMMITTRANSACTION_REQUEST) ) 
-	{
-	    return CegoDbHandler::COMMITTRANSACTION;
-	}
-	else if (  docType == Chain(XML_ROLLBACKTRANSACTION_REQUEST) ) 
-	{
-	    return CegoDbHandler::ROLLBACKTRANSACTION;
-	}
-	else if (  docType == Chain(XML_GETTID_REQUEST) ) 
-	{
-	    return CegoDbHandler::GETTID;
-	}
 	else if (  docType == Chain(XML_SESSION_CLOSE) ) 
 	{
 	    return CegoDbHandler::SESSION_CLOSE;
@@ -2184,84 +2069,6 @@ CegoDbHandler::RequestType CegoDbHandler::acceptRequest()
 	    _serTid = _pSer->readChain().asUnsignedLongLong();
 	    return CegoDbHandler::QUERYABORT;
 	}
-	else if ( req == Chain(SER_DBPRODINFO) ) 
-	{
-	    return CegoDbHandler::DBPRODINFO;
-	}
-	else if (  req == Chain(SER_CREATETABLE) ) 
-	{
-	    return CegoDbHandler::CREATETABLE;
-	}
-	else if (  req == Chain(SER_CREATEVIEW) ) 
-	{
-	    return CegoDbHandler::CREATEVIEW;
-	}
-	else if (  req == Chain(SER_CREATEPROCEDURE) ) 
-	{
-	    return CegoDbHandler::CREATEPROCEDURE;
-	}
-	else if (  req == Chain(SER_CREATECHECK) ) 
-	{
-	    return CegoDbHandler::CREATECHECK;
-	}
-	else if (  req == Chain(SER_ALTERTABLE) ) 
-	{
-	    return CegoDbHandler::ALTERTABLE;
-	}
-	else if (  req == Chain(SER_CREATEINDEX) ) 
-	{
-	    return CegoDbHandler::CREATEINDEX;
-	}
-	else if (  req == Chain(SER_INSERT) ) 
-	{
-	    return CegoDbHandler::INSERT;
-	}
-	else if (  req == Chain(SER_DELETE) ) 
-	{
-	    _serAffected = _pSer->readChain().asUnsigned();
-	    return CegoDbHandler::DELETETABLE;
-	}
-	else if (  req == Chain(SER_UPDATE) ) 
-	{
-	    _serAffected = _pSer->readChain().asUnsigned();
-	    return CegoDbHandler::UPDATE;
-	}
-	else if (  req == Chain(SER_OBJECTINFO) ) 
-	{
-	    return CegoDbHandler::OBJECTINFO;
-	}
-	else if (  req == Chain(SER_DROP_OBJECT) ) 
-	{
-	    return CegoDbHandler::DROPOBJECT;
-	}
-	else if (  req == Chain(SER_GETTABLE) ) 
-	{
-	    return CegoDbHandler::GETTABLE;
-	}
-	else if (  req == Chain(SER_GETOBJLIST) ) 
-	{
-	    return CegoDbHandler::GETOBJLIST;
-	}
-	else if (  req == Chain(SER_GETOBJLISTBYTABLE) ) 
-	{
-	    return CegoDbHandler::GETOBJLISTBYTABLE;
-	}
-	else if (  req == Chain(SER_OBJRENAME) ) 
-	{
-	    return CegoDbHandler::OBJRENAME;
-	}
-	else if (  req == Chain(SER_REORG) ) 
-	{
-	    return CegoDbHandler::REORGOBJ;
-	}
-	else if (  req == Chain(SER_SYNC) ) 
-	{
-	    return CegoDbHandler::SYNC;
-	}
-	else if (  req == Chain(SER_GETPAGECOUNT) ) 
-	{
-	    return CegoDbHandler::GETPAGECOUNT;
-	}
 	else if (  req == Chain(SER_PUTBLOB) ) 
 	{
 	    _serTableSet = _pSer->readChain();
@@ -2294,22 +2101,6 @@ CegoDbHandler::RequestType CegoDbHandler::acceptRequest()
 	{
 	    return CegoDbHandler::DELCLOB;
 	}
-	else if (  req == Chain(SER_STARTTRANSACTION) ) 
-	{
-	    return CegoDbHandler::STARTTRANSACTION;
-	}
-	else if (  req == Chain(SER_COMMITTRANSACTION) ) 
-	{
-	    return CegoDbHandler::COMMITTRANSACTION;
-	}
-	else if (  req == Chain(SER_ROLLBACKTRANSACTION) ) 
-	{
-	    return CegoDbHandler::ROLLBACKTRANSACTION;
-	}
-	else if (  req == Chain(SER_GETTID) ) 
-	{
-	    return CegoDbHandler::GETTID;
-	}
 	else if (  req == Chain(SER_SESSION_CLOSE) ) 
 	{
 	    return CegoDbHandler::SESSION_CLOSE;
