@@ -43,34 +43,12 @@ public:
     enum RequestType { QUERY,
 		       QUERYABORT,
 		       DBPRODINFO,
-		       INSERT, 
-		       DELETETABLE,
-		       UPDATE,
-		       CREATETABLE, 
-		       CREATEVIEW,
-		       CREATEPROCEDURE, 
-		       ALTERTABLE, 
-		       DROPOBJECT, 
-		       CREATEINDEX,
-		       CREATECHECK,
-		       OBJECTINFO, 
-		       GETTABLE, 
-		       GETOBJLIST,
-		       GETOBJLISTBYTABLE,
-		       OBJRENAME,
-		       REORGOBJ,
-		       SYNC,
-		       GETPAGECOUNT,
 		       PUTBLOB,
 		       GETBLOB,
 		       DELBLOB,
 		       PUTCLOB,
 		       GETCLOB,
 		       DELCLOB,
-		       STARTTRANSACTION,
-		       COMMITTRANSACTION,
-		       ROLLBACKTRANSACTION,
-		       GETTID,
 		       SESSION_CLOSE,
 		       REQTIMEOUT,
 		       UNKNOWN };
