@@ -29,7 +29,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoExpOutStream::CegoExpOutStream(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoDistManager* pGTM, CegoAdminHandler* pAH)
+CegoExpOutStream::CegoExpOutStream(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, CegoQueryManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _pAH = pAH;
