@@ -33,7 +33,7 @@
 #include "CegoFunction.h"
 #include "CegoAggregation.h"
 
-class CegoDistManager;
+class CegoQueryManager;
 class CegoExpr;
 class CegoSelect;
 class CegoCaseCond;
@@ -45,7 +45,7 @@ class CegoFactor {
     
     enum FacType { CONSTVAL, VAR, EXPR, FETCH, ATTR, FUNCTION, QUERY, AGGREGATION, CASECOND, CONDITION };
 
-    CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoFactor(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoFactor(const CegoFactor& pf);
     CegoFactor(const Chain& varName);
     CegoFactor(const CegoFieldValue& fv);
@@ -110,7 +110,7 @@ class CegoFactor {
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     ListT<CegoAggregation*> getAggregationList();
