@@ -47,59 +47,59 @@ public:
 
     void setReadOnly(bool isReadOnly);
     
-    void setBackup(int fileId, bool m);
+    void setBackup(unsigned fileId, bool m);
 
     bool needPageBackup(PageIdType pageId);
-    bool isPageMarked(PageIdType pageId, int fileId);
+    bool isPageMarked(PageIdType pageId, unsigned fileId);
 
-    void initDataFile(int tabSetId, const Chain& path, int fileId, int numPages, PageIdType pageOffset, FileType ft);
+    void initDataFile(unsigned tabSetId, const Chain& path, unsigned fileId, unsigned numPages, PageIdType pageOffset, FileType ft);
 
-    void regDataFile(int tabSetId, const Chain& path, int fileId, CegoLockHandler* pLockHandle);
+    void regDataFile(unsigned tabSetId, const Chain& path, unsigned fileId, CegoLockHandler* pLockHandle);
 
-    void resetDataFile(int fileId);
+    void resetDataFile(unsigned fileId);
 	
     void writePage(PageIdType pageId, unsigned fixStat, char* pageData, CegoLockHandler* pLockHandle);
-    void readPage(PageIdType pageId, int& tabSetId, unsigned& fixStat, char* pageData, CegoLockHandler* pLockHandle);
+    void readPage(PageIdType pageId, unsigned& tabSetId, unsigned& fixStat, char* pageData, CegoLockHandler* pLockHandle);
     
     void claimPage(PageIdType pageId, CegoLockHandler* pLockHandle);
-    void allocatePage(int tabSetId, FileType ft, PageIdType& pageId, CegoLockHandler* pLockHandle, unsigned* &fbm, int& fbmSize, bool doAppend = false);
-    void releasePage(PageIdType pageId, CegoLockHandler* pLockHandle, unsigned* &fbm, int& fbmSize);
+    void allocatePage(unsigned tabSetId, FileType ft, PageIdType& pageId, CegoLockHandler* pLockHandle, unsigned* &fbm, unsigned& fbmSize, bool doAppend = false);
+    void releasePage(PageIdType pageId, CegoLockHandler* pLockHandle, unsigned* &fbm, unsigned& fbmSize);
 
-    void releaseFiles(int tabSetId);
+    void releaseFiles(unsigned tabSetId);
 
-    int getNumPages(int fileId);
-    int getNumUsedPages(int fileId, CegoLockHandler* pLockHandle);
+    unsigned getNumPages(unsigned fileId);
+    unsigned getNumUsedPages(unsigned fileId, CegoLockHandler* pLockHandle);
 
-    PageIdType getPageOffset(int fileId);
+    PageIdType getPageOffset(unsigned fileId);
 
     PageIdType getMaxPageOffset();
     
     bool isClaimed(PageIdType pageId, CegoLockHandler *pLockHandle);
     
-    void writeFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockHandle);
+    void writeFBM(unsigned fileId, unsigned *fbm, CegoLockHandler *pLockHandle);
 
-    int getFileIdForPageId(PageIdType pageId);
+    unsigned getFileIdForPageId(PageIdType pageId);
 
     void commitPageEntry(PageIdType pageId);
-    int cleanPages(CegoLockHandler *pLockHandle);
+    unsigned cleanPages(CegoLockHandler *pLockHandle);
     
 protected:
     
-    int _pageSize;
+    unsigned _pageSize;
 
 private:
 
-    int getFBMSize(int fileId);
-    void readFBM(int fileId, unsigned *fbm, CegoLockHandler *pLockHandle);
+    unsigned getFBMSize(unsigned fileId);
+    void readFBM(unsigned fileId, unsigned *fbm, CegoLockHandler *pLockHandle);
     void markPage(PageIdType pageId);
-    File* getHandle(int fileId);
+    File* getHandle(unsigned fileId);
     void printBitMap(unsigned bm);
-    int mapDiff(unsigned bm1, unsigned bm2);
+    unsigned mapDiff(unsigned bm1, unsigned bm2);
 	    
     bool _isReg[FILMNG_MAXDATAFILE];
-    int _tabSetId[FILMNG_MAXDATAFILE];
-    int _fileType[FILMNG_MAXDATAFILE];
-    int _numPages[FILMNG_MAXDATAFILE];
+    unsigned _tabSetId[FILMNG_MAXDATAFILE];
+    unsigned _fileType[FILMNG_MAXDATAFILE];
+    unsigned _numPages[FILMNG_MAXDATAFILE];
     PageIdType _pageOffset[FILMNG_MAXDATAFILE];
     File* _fhList[FILMNG_MAXDATAFILE];
     Chain _path[FILMNG_MAXDATAFILE];
@@ -107,7 +107,7 @@ private:
     unsigned* _commitMask[FILMNG_MAXDATAFILE];
     bool _fbmMask[FILMNG_MAXDATAFILE];
     PageIdType _appendPos[FILMNG_MAXDATAFILE];
-    int _appendFid;
+    unsigned _appendFid;
     bool _isReadOnly;
     
     unsigned long _modId;
