@@ -29,7 +29,7 @@
 #include "CegoProcBlock.h"
 
 class CegoProcedure;
-class CegoDistManager;
+class CegoQueryManager;
 class CegoTableManager;
 class CegoAggregation;
 class CegoExpr;
@@ -84,9 +84,9 @@ public:
     
     CegoFunction(FunctionType funcType);
     CegoFunction(FunctionType funcType, ListT<CegoExpr*>& exprList);
-    CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId);
-    CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type);
-    CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList);
+    CegoFunction(char* buf, CegoQueryManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoFunction(CegoQueryManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type);
+    CegoFunction(CegoQueryManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList);
     
     ~CegoFunction();
 
@@ -125,7 +125,7 @@ public:
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     CegoFunction* clone(bool isAttrRef = false);
@@ -140,7 +140,7 @@ private:
 
     CegoProcedure* loadProcedure(unsigned tabSetId, const Chain& procName) const;
   
-    CegoDistManager* _pTabMng;
+    CegoQueryManager* _pTabMng;
     CegoProcedure* _pProc;	    
     Chain _funcName;
     Chain _counterId;  
