@@ -26,14 +26,14 @@
 #include "CegoXMLdef.h"
 #include "CegoField.h"
 #include "CegoObject.h"
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoTypeConverter.h"
 
 // POSIX INCLUDES
 #include <string.h>
 #include <stdlib.h>
 
-CegoImpInStream::CegoImpInStream(const Chain& tableSet, CegoDistManager* pGTM, CegoAdminHandler* pAH)
+CegoImpInStream::CegoImpInStream(const Chain& tableSet, CegoQueryManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _tableSet = tableSet;
@@ -43,7 +43,7 @@ CegoImpInStream::CegoImpInStream(const Chain& tableSet, CegoDistManager* pGTM, C
     _modId = _pDBMng->getModId("CegoImpInStream");
 }
 
-CegoImpInStream::CegoImpInStream(const Chain& tableSet, const Chain& tableName, CegoDistManager* pGTM, CegoAdminHandler* pAH)
+CegoImpInStream::CegoImpInStream(const Chain& tableSet, const Chain& tableName, CegoQueryManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _tableSet = tableSet;
@@ -160,7 +160,7 @@ void CegoImpInStream::putFirst(Element* pParent, const Chain& name, const ListT<
 	    }
 
 	    ListT<CegoField> idxList;
-	    _pGTM->createDistDataTable(_tableSet, tabName, CegoObject::TABLE, _schema, idxList);		
+	    _pGTM->createQueryTable(_tableSet, tabName, _schema, idxList);		
 	    _pGTM->setAppend(true);
 	}
 	insertData(tabName, attrList, dataList);
