@@ -68,7 +68,7 @@ CegoLockHandler::CegoLockHandler(CegoDatabaseManager* pDBMng)
 	+ _numDataFileSema
 	+ _numBufferPoolSema;
     
-    _lockCount = new int[_numSema];
+    _lockCount = new unsigned[_numSema];
 
     _recordLock = (RecordLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct RecordLock));
     _rbRecordLock = (RecordLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct RecordLock));
@@ -78,8 +78,8 @@ CegoLockHandler::CegoLockHandler(CegoDatabaseManager* pDBMng)
     _idxPageLock = (PageLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct PageLock));
     _rbPageLock = (PageLock*)malloc( LCKMNG_NUMLOCKS * sizeof( struct PageLock));
     
-    int i;
-    for (int i = 0; i<_numSema; i++)
+    unsigned i;
+    for (i = 0; i<_numSema; i++)
     {
 	_lockCount[i]=0;
     }
@@ -123,15 +123,15 @@ void CegoLockHandler::initLocks()
 {
     _lockArray = new ThreadLock*[_numSema];
 
-    for (int i = 0; i<_numSema; i++)
+    for (unsigned i = 0; i<_numSema; i++)
     {
 	_lockArray[i] = new ThreadLock();
 	_lockArray[i]->init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
     }
 
-    int low = 0;
-    int high = _numRecSema;
-    int semId;
+    unsigned low = 0;
+    unsigned high = _numRecSema;
+    unsigned semId;
 
     for (  semId = low ; semId < high ; semId++ )
     {
@@ -273,7 +273,7 @@ void CegoLockHandler::deleteLocks()
 {
     if ( _lockArray != 0 )
     {
-	for (int i = 0; i<_numSema; i++)
+	for (unsigned i = 0; i<_numSema; i++)
 	    delete _lockArray[i];
 	delete _lockArray;
 	_lockArray = 0;
@@ -282,12 +282,12 @@ void CegoLockHandler::deleteLocks()
 
 unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-    int timeout = _recLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _recLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int semId = ( dp.getPageId() + dp.getOffset()) % _numRecSema;
+    unsigned semId = ( dp.getPageId() + dp.getOffset()) % _numRecSema;
 
-    int i=0;
+    unsigned i=0;
     while ( _recordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS )
     {
 	i++;
@@ -349,14 +349,14 @@ unsigned long long CegoLockHandler::lockRecord(const CegoDataPointer& dp, enum L
 
 void CegoLockHandler::unlockRecord(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _recordLock[i].lockId != lockId )
     {
 	i++;
     }
     if ( _recordLock[i].lockId == lockId )
     {	
-	int semId = _recordLock[i].semId;
+	unsigned semId = _recordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -379,12 +379,12 @@ void CegoLockHandler::unlockRecord(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockRBRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-    int timeout = _recLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _recLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int semId = _numRecSema + ( dp.getPageId() + dp.getOffset()) % _numRBRecSema;
+    unsigned semId = _numRecSema + ( dp.getPageId() + dp.getOffset()) % _numRBRecSema;
 
-    int i=0;
+    unsigned i=0;
     while ( _rbRecordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -445,14 +445,14 @@ unsigned long long CegoLockHandler::lockRBRecord(const CegoDataPointer& dp, enum
 
 void CegoLockHandler::unlockRBRecord(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _rbRecordLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_rbRecordLock[i].lockId == lockId)
     {	
-	int semId = _rbRecordLock[i].semId;
+	unsigned semId = _rbRecordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -475,14 +475,14 @@ void CegoLockHandler::unlockRBRecord(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockSysRecord(const CegoDataPointer& dp, enum LockMode lockMode)
 {
-    int timeout = _recLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _recLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int semId = _numRecSema
+    unsigned semId = _numRecSema
 	+ _numRBRecSema
 	+ ( dp.getPageId() + dp.getOffset()) % _numSysRecSema;
 
-    int i=0;
+    unsigned i=0;
     while ( _sysRecordLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -543,14 +543,14 @@ unsigned long long CegoLockHandler::lockSysRecord(const CegoDataPointer& dp, enu
 
 void CegoLockHandler::unlockSysRecord(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _sysRecordLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_sysRecordLock[i].lockId == lockId)
     {	
-	int semId = _sysRecordLock[i].semId;
+	unsigned semId = _sysRecordLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -573,15 +573,15 @@ void CegoLockHandler::unlockSysRecord(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockSysPage(PageIdType pageId, enum LockMode lockMode)
 {
-    int semId = _numRecSema 
+    unsigned semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema 
 	+ pageId % _numSysPageSema;
 
-    int timeout = _pageLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _pageLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int i=0;
+    unsigned i=0;
     while ( _sysPageLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -644,14 +644,14 @@ unsigned long long CegoLockHandler::lockSysPage(PageIdType pageId, enum LockMode
 
 void CegoLockHandler::unlockSysPage(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _sysPageLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_sysPageLock[i].lockId == lockId)
     {
-	int semId = _sysPageLock[i].semId;
+	unsigned semId = _sysPageLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -700,16 +700,16 @@ void CegoLockHandler::unlockData(CegoObject::ObjectType type, unsigned long long
 
 unsigned long long CegoLockHandler::lockDataPage(PageIdType pageId, enum LockMode lockMode)
 {
-    int semId = _numRecSema 
+    unsigned semId = _numRecSema 
 	+ _numRBRecSema
 	+ _numSysRecSema 
 	+ _numSysPageSema 
 	+ ( pageId % _numDataPageSema );
 
-    int timeout = _pageLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _pageLockTimeout;
+    unsigned numTries = _numLockTries;
     
-    int i=0;
+    unsigned i=0;
     while ( _dataPageLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -773,14 +773,14 @@ unsigned long long CegoLockHandler::lockDataPage(PageIdType pageId, enum LockMod
 
 void CegoLockHandler::unlockDataPage(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _dataPageLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_dataPageLock[i].lockId == lockId)
     {
-	int semId = _dataPageLock[i].semId;
+	unsigned semId = _dataPageLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -803,17 +803,17 @@ void CegoLockHandler::unlockDataPage(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockIndexPage(PageIdType pageId, enum LockMode lockMode)
 {
-    int semId = _numRecSema
+    unsigned semId = _numRecSema
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
 	+ _numDataPageSema 
 	+ ( pageId  % _numIdxPageSema );
 
-    int timeout = _pageLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _pageLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int i=0;
+    unsigned i=0;
     while ( _idxPageLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -877,14 +877,14 @@ unsigned long long CegoLockHandler::lockIndexPage(PageIdType pageId, enum LockMo
 
 void CegoLockHandler::unlockIndexPage(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _idxPageLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_idxPageLock[i].lockId == lockId)
     {
-	int semId = _idxPageLock[i].semId;
+	unsigned semId = _idxPageLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -907,7 +907,7 @@ void CegoLockHandler::unlockIndexPage(unsigned long long lockId)
 
 unsigned long long CegoLockHandler::lockRBPage(PageIdType pageId, enum LockMode lockMode)
 {
-    int semId = _numRecSema 
+    unsigned semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
@@ -915,10 +915,10 @@ unsigned long long CegoLockHandler::lockRBPage(PageIdType pageId, enum LockMode
 	+ _numIdxPageSema 
 	+ ( pageId % _numRBPageSema );
 
-    int timeout = _pageLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _pageLockTimeout;
+    unsigned numTries = _numLockTries;
 
-    int i=0;
+    unsigned i=0;
     while ( _rbPageLock[i].lockId != 0 && i < LCKMNG_NUMLOCKS)
     {
 	i++;
@@ -983,14 +983,14 @@ unsigned long long CegoLockHandler::lockRBPage(PageIdType pageId, enum LockMode
 
 void CegoLockHandler::unlockRBPage(unsigned long long lockId)
 {
-    int i=0;
+    unsigned i=0;
     while (i < LCKMNG_NUMLOCKS && _rbPageLock[i].lockId != lockId )
     {
 	i++;
     }
     if (_rbPageLock[i].lockId == lockId)
     {
-	int semId = _rbPageLock[i].semId;
+	unsigned semId = _rbPageLock[i].semId;
 	
 	if ( _lockCount[semId] > 1 )
 	{
@@ -1011,9 +1011,9 @@ void CegoLockHandler::unlockRBPage(unsigned long long lockId)
     }
 }
 
-void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
+void CegoLockHandler::lockDataFile(unsigned fileId, enum LockMode lockMode)
 {
-    int semId = _numRecSema 
+    unsigned semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema 
 	+ _numSysPageSema 
@@ -1022,8 +1022,8 @@ void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
 	+ _numRBPageSema 
 	+ fileId % _numDataFileSema;
 
-    int timeout = _fileLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _fileLockTimeout;
+    unsigned numTries = _numLockTries;
 
     if ( _lockCount[semId] == 0 )
     {
@@ -1072,9 +1072,9 @@ void CegoLockHandler::lockDataFile(int fileId, enum LockMode lockMode)
     }    
 }
 
-void CegoLockHandler::unlockDataFile(int fileId)
+void CegoLockHandler::unlockDataFile(unsigned fileId)
 {
-    int semId = _numRecSema
+    unsigned semId = _numRecSema
 	+ _numRBRecSema 
 	+ _numSysRecSema 
 	+ _numSysPageSema 
@@ -1094,10 +1094,10 @@ void CegoLockHandler::unlockDataFile(int fileId)
     }
 }
 
-void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
+void CegoLockHandler::lockBufferPool(unsigned hashId, enum LockMode lockMode)
 {    
     
-    int semId = _numRecSema
+    unsigned semId = _numRecSema
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
@@ -1107,8 +1107,8 @@ void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
 	+ _numDataFileSema 
 	+ hashId % _numBufferPoolSema;
 
-    int timeout = _poolLockTimeout;
-    int numTries = _numLockTries;
+    unsigned timeout = _poolLockTimeout;
+    unsigned numTries = _numLockTries;
     
     if ( _lockCount[semId] == 0 )
     {
@@ -1159,9 +1159,9 @@ void CegoLockHandler::lockBufferPool(int hashId, enum LockMode lockMode)
     }    
 }
 
-void CegoLockHandler::unlockBufferPool(int hashId)
+void CegoLockHandler::unlockBufferPool(unsigned hashId)
 {
-    int semId = _numRecSema 
+    unsigned semId = _numRecSema 
 	+ _numRBRecSema 
 	+ _numSysRecSema
 	+ _numSysPageSema 
@@ -1191,7 +1191,7 @@ void CegoLockHandler::unlockBufferPool(int hashId)
 void CegoLockHandler::lockBufferPool()
 {
     _poolLockRange=0;
-    for ( int i=0; i<_numBufferPoolSema; i++ )
+    for ( unsigned i=0; i<_numBufferPoolSema; i++ )
     {
 	lockBufferPool(_poolLockRange, WRITE);
 	_poolLockRange=i+1;
@@ -1200,11 +1200,11 @@ void CegoLockHandler::lockBufferPool()
 
 void CegoLockHandler::unlockBufferPool()
 {
-    for ( int i=0; i<_poolLockRange; i++ )
+    for ( unsigned i=0; i<_poolLockRange; i++ )
 	unlockBufferPool(i);
 }
 
-void CegoLockHandler::getLockStat(int semId, Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoLockHandler::getLockStat(unsigned semId, Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {   
     lockName = _lockArray[semId]->getId();
     lockCount = _lockArray[semId]->numLockTry();
@@ -1219,7 +1219,7 @@ void CegoLockHandler::getLockStat(int semId, Chain& lockName, int& lockCount, un
 	sumWrDelay = _lockArray[semId]->sumWriteDelay() / LCKMNG_DELRES;
 }
 
-void CegoLockHandler::getAggLockStat(const Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoLockHandler::getAggLockStat(const Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockCount = 0;
     numRdLock = 0;
@@ -1228,7 +1228,7 @@ void CegoLockHandler::getAggLockStat(const Chain& lockGroup, int& numLock, int&
     sumWrDelay = 0;
     numLock = 0;
 
-    for ( int semId=0; semId<_numSema; semId++ )
+    for ( unsigned semId=0; semId<_numSema; semId++ )
     {	
 	Tokenizer tok(_lockArray[semId]->getId(), "-");
 	
