@@ -26,7 +26,6 @@
 
 // CEGO INCLUDES
 #include "CegoFileHandler.h"
-#include "CegoLogHandler.h"
 #include "CegoLogRecord.h"
 #include "CegoXMLSpace.h"
 #include "CegoDefs.h"
@@ -47,9 +46,6 @@ public:
     void resetLog(unsigned tabSetId);
     bool isActive(unsigned tabSetId);
     LogResult logAction(unsigned tabSetId, CegoLogRecord& logRec, bool flushLog = true);
-    void allocateLogConnection(unsigned tabSetId, const Chain& tableSet, const Chain& logHost, unsigned logPort, const Chain& logUser, const Chain& logPwd);
-    bool hasLogConnection(unsigned tabSetId);
-    void releaseLogConnection(unsigned tabSetId);
     void setLogFile(unsigned tabSetId, const Chain& logFile, bool readOnly);
     unsigned long long getMinLSN(unsigned tabSetId);
     unsigned long long getMaxLSN(unsigned tabSetId);
@@ -79,8 +75,6 @@ private:
     unsigned long long _lsn[TABMNG_MAXTABSET];
     unsigned _logPos[TABMNG_MAXTABSET];
     bool _logActive[TABMNG_MAXTABSET];
-    CegoLogHandler* _pLogHandler[TABMNG_MAXTABSET];
-    NetHandler* _pNetHandler[TABMNG_MAXTABSET];
 
     unsigned long _modId;
 };
