@@ -40,15 +40,13 @@
 
 // CEGO INCLUDES
 #include "CegoDbThreadPool.h"
-#include "CegoLogThreadPool.h"
 #include "CegoAdminThreadPool.h"
 #include "CegoDatabaseManager.h"
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoAction.h"
 #include "CegoXMLdef.h"
-#include "CegoBeatThread.h"
-#include "CegoMediatorThread.h"
-#include "CegoBeatConnection.h"
+#include "CegoSigCatch.h"
+#include "CegoArchiveThread.h"
 #include "CegoXPorter.h"
 #include "CegoXMLdef.h"
 #include "CegoModule.h"
@@ -81,7 +79,7 @@
   Query Cache Mode:   cego --mode=querycache --tableset=<string> [ --enable ]\n\
                          [ --maxsize=<int> ] [ --maxentry=<int> ] [ --hashrange=<int> ] [ --threshold=<int> ] --dbxml=<filename>\n\
 \n\
-  Log Shitt Mode:     cego --mode=shiftactive --tableset=<string>  --dbxml=<filename>\n\
+  Log Shift Mode:     cego --mode=shiftactive --tableset=<string>  --dbxml=<filename>\n\
 \n\
   Export Mode:        cego --mode={xmlexport|binexport|plainexport} --expfile=<filename>\n \
                            --tableset=<string> --dbxml=<filename> --user=<string>/<string>\n\
@@ -94,9 +92,9 @@
 \n\
   Daemon Mode:        cego --mode=[daemon|server] --dbxml=<filename> [--tableset=<string>,<string>,... ]\n\
                            [ --cleanup ] [ --forceload ] [ --cpdump ]\n\
-                           [ --numdbthread=<int> ] [ --numadminthread=<int> ] [ --numlogthread=<int> ]\n\
-                           [ --poolsize=[<numseg>x]<segsize> ] [ --pidfile=<filename> ] [ --protocol={serial|xml|fastserial}]\n\
-                           [ --master=<host>:<port>:<user>:<passwd> ]\n\
+                           [ --numdbthread=<int> ] [ --numadminthread=<int> ]\n\
+                           [ --poolsize=[<numseg>x]<segsize> ] [ --pidfile=<filename> ]\n\
+                           [ --protocol={serial|xml|fastserial}]\n\
 \n\
   General Options:    [ --logfile=<filename> ] [--syslog=yes|no ] [ --lockfile=<filename> ] [ --lockexpire=<int> ] [ --lockstat ] [ --fsync ]\n"
 
@@ -109,7 +107,6 @@
 #define DEFAULTPOOLSIZE "3x1000"
 #define DEFAULTDBTHREADNUM 10
 #define DEFAULTADMINTHREADNUM 5
-#define DEFAULTLOGTHREADNUM 3
 #define DEFAULTBEATPORT 2000
 #define DEFAULTBEATUSER "cgadm"
 #define DEFAULTBEATPWD "cgadm"
@@ -217,7 +214,6 @@ int main(int argc, char **argv)
     longOpt.addOpt("ignore");
     longOpt.addOpt("numdbthread", Chain(DEFAULTDBTHREADNUM));
     longOpt.addOpt("numadminthread", Chain(DEFAULTADMINTHREADNUM));
-    longOpt.addOpt("numlogthread", Chain(DEFAULTLOGTHREADNUM));
     longOpt.addOpt("master");
     // query cache options
     longOpt.addOpt("enable");
@@ -315,13 +311,6 @@ int main(int argc, char **argv)
 	cerr << "Invalid value for numadminthread : " << numAdminThread << endl;
 	exit(1);
     }
-
-    Chain numLogThread = longOpt.getOptValue("numlogthread");
-    if ( numLogThread.asUnsigned() <= 0 )
-    {
-	cerr << "Invalid value for numlogthread : " << numLogThread << endl;
-	exit(1);
-    }
     
     Chain mode = longOpt.getOptValue("mode");
     
@@ -479,7 +468,6 @@ int init(GetLongOpt& longOpt)
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain dbName = longOpt.getOptValue("dbname");
 	Chain hostname = longOpt.getOptValue("hostname");
-	Chain pidfile = longOpt.getOptValue("pidfile");
 	Chain pgsize = longOpt.getOptValue("pgsize");
 	Chain dbport = longOpt.getOptValue("dbport");
 	Chain admport = longOpt.getOptValue("admport");
@@ -519,8 +507,7 @@ int init(GetLongOpt& longOpt)
 
 	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 
-	pDBMng->initXml(dbName, pgsize.asUnsigned(), hostname, dbport.asUnsigned(), admport.asUnsigned(), logport.asUnsigned(), pidfile, logLevel,
-			csmode, qescmode == Chain(XML_ON_VALUE) );
+	pDBMng->initXml(dbName, pgsize.asUnsigned(), hostname, dbport.asUnsigned(), admport.asUnsigned(), logport.asUnsigned(), logLevel, csmode, qescmode == Chain(XML_ON_VALUE) );
 	
 	delete pDBMng;
     }
@@ -854,15 +841,9 @@ int defineTableSet(GetLongOpt& longOpt)
 	unsigned sysFid = pDBMng->nextTSID();
 	
 	unsigned tmpFid = pDBMng->nextFID();
-	
-	Chain dbHost;
-	pDBMng->getDBHost(dbHost);
-	
+		
 	pDBMng->addTableSetDef(tableSet, 
 			       tsRoot,
-			       dbHost, 
-			       dbHost, 
-			       dbHost, 
 			       sysFid, 
 			       tmpFid, 
 			       sysSize, 
@@ -935,7 +916,7 @@ int createTableSet(GetLongOpt& longOpt)
 
 	pLockHandler->initLocks();	    
 	
-	CegoDistManager tabMng(pDBMng);
+	CegoQueryManager tabMng(pDBMng);
 
 	Chain status = pDBMng->getTableSetRunState(tableSet);
 	
@@ -946,6 +927,7 @@ int createTableSet(GetLongOpt& longOpt)
 	}
 
 	pDBMng->log(modId, Logger::NOTICE, Chain("Creating tableset ") + tableSet + Chain(" ..."));
+
 	tabMng.createTableSet(tableSet);
 
 	pDBMng->log(modId, Logger::NOTICE, Chain("Tableset ") + tableSet + Chain(" created"));
@@ -1026,8 +1008,8 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	unsigned long modId = pDBMng->getModId("CegoMain");
 	
 	CegoLockHandler* pLockHandler = 0;
-	CegoLogThreadPool* pLogPool = 0;
-	CegoDistManager* pTabMng = 0;
+	CegoQueryManager* pTabMng = 0;
+	CegoArchiveThread* pArchThread = 0;
 	
 	try
 	{
@@ -1042,11 +1024,11 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 #ifdef CGDEBUG	
 		pDBMng->log(modId, Logger::DEBUG, Chain("Creating log threadpool ..."));
 #endif
-		pLogPool = new CegoLogThreadPool(pDBMng);
-		pLogPool->start(0);
+		pArchThread = new CegoArchiveThread(pDBMng);
+		pArchThread->start(0);
 	    }
 	    
-	    pTabMng = new CegoDistManager(pDBMng);
+	    pTabMng = new CegoQueryManager(pDBMng);
 
 	    pTabMng->setActiveUser(tableSet, user, password);
 	    
@@ -1054,10 +1036,8 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	    pDBMng->log(modId, Logger::DEBUG, Chain("Starting tableset ") + tableSet + Chain(" ..."));
 #endif	    
 	    
-	    Chain dbHost;
-	    pDBMng->getDBHost(dbHost);
 
-	    pTabMng->startDistTableSet(tableSet, dbHost, false, true, true, false);
+	    pTabMng->startQueryTableSet(tableSet, false, true, true, false);
 
 	    unsigned tabSetId = pDBMng->getTabSetId(tableSet);
 	    
@@ -1082,7 +1062,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 		xp.binImportTableSet(tableSet, false, impFileName, true);
 	    }
 
-	    pTabMng->stopDistTableSet(tableSet, true);
+	    pTabMng->stopTableSet(tableSet, true);
 	    
 	    pDBMng->doc2Xml();	    
 	}
@@ -1102,8 +1082,8 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	    errorMsg=Chain("Import failed, see log for details");		
 	}
 	
-	if ( pLogPool )
-	    delete pLogPool;
+	if ( pArchThread )
+	    delete pArchThread;
 	
 	if ( pTabMng )
 	    delete pTabMng;
@@ -1196,8 +1176,8 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	unsigned long modId = pDBMng->getModId("CegoMain");
 		
 	CegoLockHandler* pLockHandler = 0;
-	CegoLogThreadPool* pLogPool = 0;
-	CegoDistManager* pTabMng = 0;
+	CegoArchiveThread* pArchThread = 0;
+	CegoQueryManager* pTabMng = 0;
 	
 	try
 	{
@@ -1213,11 +1193,11 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 		pDBMng->log(modId, Logger::DEBUG, Chain("Creating log threadpool ..."));
 #endif
 
-		pLogPool = new CegoLogThreadPool(pDBMng);
-		pLogPool->start(0);
+		pArchThread = new CegoArchiveThread(pDBMng);
+		pArchThread->start(0);
 	    }
 	    
-	    pTabMng = new CegoDistManager(pDBMng);
+	    pTabMng = new CegoQueryManager(pDBMng);
 
 	    pTabMng->setActiveUser(tableSet, user, password);
 	    
@@ -1225,10 +1205,8 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	    pDBMng->log(modId, Logger::DEBUG, Chain("Starting tableset ") + tableSet + Chain(" ..."));    	
 #endif    
 
-	    Chain dbHost;
-	    pDBMng->getDBHost(dbHost);
 
-	    pTabMng->startDistTableSet(tableSet, dbHost, false, false, false, false);
+	    pTabMng->startQueryTableSet(tableSet, false, false, false, false);
 	    
 	    CegoXPorter xp(pTabMng);
 	    
@@ -1248,7 +1226,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 		xp.binExportTableSet(tableSet, false, expFileName, true);
 	    }
 	    
-	    pTabMng->stopDistTableSet(tableSet, true);
+	    pTabMng->stopTableSet(tableSet, true);
 	    
 	    pDBMng->doc2Xml();	    
 	}
@@ -1268,8 +1246,8 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	    errorMsg=Chain("Export failed, see log for details");		
 	}
 	
-	if ( pLogPool )
-	    delete pLogPool;
+	if ( pArchThread )
+	    delete pArchThread;
 	
 	if ( pTabMng )
 	    delete pTabMng;
@@ -1311,8 +1289,8 @@ int runBatch(GetLongOpt& longOpt)
     
     CegoDatabaseManager* pDBMng = 0;
     CegoLockHandler* pLockHandler = 0;
-    CegoLogThreadPool* pLogPool = 0;
-    CegoDistManager* pTabMng = 0;
+    CegoArchiveThread* pArchThread = 0;
+    CegoQueryManager* pTabMng = 0;
     CegoAction* pAction = 0;
     
     try 
@@ -1376,11 +1354,11 @@ int runBatch(GetLongOpt& longOpt)
 	    pDBMng->log(modId, Logger::DEBUG, Chain("Creating log threadpool ..."));
 #endif
 	    
-	    pLogPool = new CegoLogThreadPool(pDBMng);
-	    pLogPool->start(0);
+	    pArchThread = new CegoArchiveThread(pDBMng);
+	    pArchThread->start(0);
 	}
 	    	    
-	pTabMng = new CegoDistManager(pDBMng);
+	pTabMng = new CegoQueryManager(pDBMng);
 	pTabMng->setActiveUser(tableSet, user, password);
 	pTabMng->setThreadId(1);
 	
@@ -1388,10 +1366,8 @@ int runBatch(GetLongOpt& longOpt)
 	pDBMng->log(modId, Logger::DEBUG, Chain("Starting tableset ") + tableSet + Chain(" ..."));
 #endif	    
 	
-	Chain dbHost;
-	pDBMng->getDBHost(dbHost);
 	
-	pTabMng->startDistTableSet(tableSet, dbHost, cleanIt, true, true, cpDump);
+	pTabMng->startQueryTableSet(tableSet, cleanIt, true, true, cpDump);
 	
 #ifdef CGDEBUG	
 	pDBMng->log(modId, Logger::DEBUG, Chain("Tableset ") + tableSet + Chain(" completed"));
@@ -1407,7 +1383,7 @@ int runBatch(GetLongOpt& longOpt)
 	
 	pDBMng->log(modId, Logger::NOTICE, Chain("Batchfile processed with exit code ") + Chain(exitCode));
 	
-	pTabMng->stopDistTableSet(tableSet, false);
+	pTabMng->stopTableSet(tableSet, false);
 	
 	pDBMng->doc2Xml();	    
 	
@@ -1422,8 +1398,8 @@ int runBatch(GetLongOpt& longOpt)
     if ( pAction )
 	delete pAction;
     
-    if ( pLogPool )
-	delete pLogPool;
+    if ( pArchThread )
+	delete pArchThread;
     
     if ( pTabMng )
 	delete pTabMng;
@@ -1452,14 +1428,13 @@ int runDaemon(GetLongOpt& longOpt)
 {
     int exitCode = 0;
 
-    CegoMediatorThread *pMedThread = 0;
+    CegoArchiveThread *pArchThread = 0;
     CegoLockHandler* pLockHandler = 0;
 
     CegoDbThreadPool* pDbPool = 0;
-    CegoLogThreadPool* pLogPool = 0;
     CegoAdminThreadPool *pAdminPool = 0;
 
-    CegoBeatThread *pBeatThread = 0;
+    CegoSigCatch *pSigCatch = 0;
     
     CegoDatabaseManager* pDBMng = 0;
     unsigned long modId = 0;
@@ -1475,7 +1450,6 @@ int runDaemon(GetLongOpt& longOpt)
 	Chain poolSize = longOpt.getOptValue("poolsize");
 	Chain numDbThread = longOpt.getOptValue("numdbthread");
 	Chain numAdminThread = longOpt.getOptValue("numadminthread");
-	Chain numLogThread = longOpt.getOptValue("numlogthread");
 	Chain master = longOpt.getOptValue("master");
 	Chain protocol = longOpt.getOptValue("protocol");
 	Chain lockExpire = longOpt.getOptValue("lockexpire");
@@ -1512,43 +1486,7 @@ int runDaemon(GetLongOpt& longOpt)
 	
 	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName, protType);
 		
-	pMedThread = new CegoMediatorThread(pDBMng);
-	    	
-	if ( master.length() != 0  && master != Chain() )
-	{
-	    Tokenizer tok(master, Chain(":"));
-	    
-	    Chain host;
-	    Chain port;
-	    Chain user;
-	    Chain passwd;
-	    
-	    tok.nextToken(host);
-	    tok.nextToken(port);
-	    tok.nextToken(user);
-	    tok.nextToken(passwd);
-
-#ifdef CGDEBUG	
-	    pDBMng->log(modId, Logger::DEBUG, Chain("Getting db spec from master host ") + host);
-#endif	
-
-	    AESCrypt aescrypt(CEGOAESKEY, CEGOAESKEYLEN);	    
-
-	    CegoBeatConnection beat;
-	    beat = CegoBeatConnection(host, port.asUnsigned(), user, aescrypt.encrypt(passwd), pDBMng);
-
-	    pDBMng->xml2Doc();
-	    pDBMng->configureLogger();
-	    pMedThread->getDbSpec(dbXML, beat.getHostName(), beat.getPortNo(), beat.getUser(), beat.getPasswd());
-	    pDBMng->setXmlDef(dbXML);
-
-	    pDBMng->xml2Doc();
-	    
-	    // setting dbHost to gethostbyname
-	    Host h;
-	    pDBMng->setDBHost(h.getName());
-	    pDBMng->doc2Xml();	   
-	}
+	pArchThread = new CegoArchiveThread(pDBMng);
 
 	pDBMng->xml2Doc();
 	pDBMng->initDoc();
@@ -1585,36 +1523,23 @@ int runDaemon(GetLongOpt& longOpt)
 	pDBMng->log(modId, Logger::DEBUG, "DB Pool is ready");
 #endif
 
-#ifdef CGDEBUG		
-	pDBMng->log(modId, Logger::DEBUG, "Creating log threadpool ...");
-#endif
-
-	pLogPool = new CegoLogThreadPool(numLogThread.asUnsigned(), pDBMng);
 
 #ifdef CGDEBUG		
 	pDBMng->log(modId, Logger::DEBUG, "Creating admin threadpool ...");
 #endif
 
-	pAdminPool = new CegoAdminThreadPool(numAdminThread.asUnsigned(), pDBMng, pDbPool, pLogPool);
+	pAdminPool = new CegoAdminThreadPool(numAdminThread.asUnsigned(), pDBMng, pDbPool);
 	
-	pDBMng->setThreadInfo(numDbThread.asUnsigned(), numAdminThread.asUnsigned(), numLogThread.asUnsigned());
+	pDBMng->setThreadInfo(numDbThread.asUnsigned(), numAdminThread.asUnsigned());
 		
-	pBeatThread = new CegoBeatThread(pDBMng);
+	pSigCatch = new CegoSigCatch(pDBMng);
 	
-	pMedThread->start(0);
+	pArchThread->start(0);
 	pDbPool->start(0);
-	pLogPool->start(0);
 	pAdminPool->start(0);
 	
 	// write pidfile
 
-	// is pidfile set in command line ?
-	if ( pidFile.length() == 0  || pidFile == Chain() )
-	{
-	    // if not, get pid file from xml
-	    pDBMng->getPidFile(pidFile);   
-	}
-
 	if ( pidFile != Chain() )
 	{
 	    File pf(pidFile);
@@ -1631,13 +1556,11 @@ int runDaemon(GetLongOpt& longOpt)
 		
 	// correct online entries 
 	ListT<Chain> corList;
-	Chain dbHost;
-	pDBMng->getDBHost(dbHost);
-	pDBMng->getActiveTableSet(dbHost, corList, true, false);
+	pDBMng->getActiveTableSet( corList, true, false);
 	
 	if ( corList.Size() > 0 )
 	{
-	    CegoDistManager tabMng(pDBMng);
+	    CegoQueryManager tabMng(pDBMng);
 	    Chain *pCor = corList.First();
 	    while ( pCor )
 	    {
@@ -1661,7 +1584,7 @@ int runDaemon(GetLongOpt& longOpt)
 	{
 	    Tokenizer tok(tableSetList, Chain(","));
 
-	   CegoDistManager tabMng(pDBMng);	
+	   CegoQueryManager tabMng(pDBMng);	
 
 	    // we have to allow the main thread to access all objects
 	    tabMng.disableAuth();
@@ -1672,7 +1595,6 @@ int runDaemon(GetLongOpt& longOpt)
 	    {
 		while ( tok.nextToken(tableSet) )
 		{
-		    Chain secondary = pDBMng->getSecondary(tableSet);
 		    
 #ifdef CGDEBUG	
 		    pDBMng->log(modId, Logger::DEBUG, Chain("Starting tableset ") + tableSet);
@@ -1685,7 +1607,7 @@ int runDaemon(GetLongOpt& longOpt)
 			throw Exception(EXLOC, msg);
 		    }
 		    
-		    tabMng.startDistTableSet(tableSet, secondary, cleanIt, true, true, cpDump);
+		    tabMng.startQueryTableSet(tableSet, cleanIt, true, true, cpDump);
 		    
 		    if ( forceload )
 		    {
@@ -1747,17 +1669,15 @@ int runDaemon(GetLongOpt& longOpt)
 
 	CegoCheckpoint cpc;
 
-	while ( ! pBeatThread->isTerminated() 
+	while ( ! pSigCatch->isTerminated() 
 		&& ! pDbPool->isTerminated() 
-		&& ! pLogPool->isTerminated() 
 		&& ! pAdminPool->isTerminated() )
 	{
-	    pBeatThread->beat();
 	    
 	    ListT<Chain> actList;
 
 	    // we get all active and online tableset, except the tablesets which actually are recovered
-	    pDBMng->getActiveTableSet(dbHost, actList, false, false);
+	    pDBMng->getActiveTableSet( actList, false, false);
 	    
 	    if ( actList.Size() > 0 )
 	    {	
@@ -1768,7 +1688,7 @@ int runDaemon(GetLongOpt& longOpt)
 		    pDBMng->log(modId, Logger::DEBUG, Chain("Checking tableset ") + *pAct + Chain(" ..."));
 #endif
 
-		    CegoDistManager tabMng(pDBMng);
+		    CegoQueryManager tabMng(pDBMng);
 		    
 		    try 
 		    {
@@ -1814,11 +1734,11 @@ int runDaemon(GetLongOpt& longOpt)
 	
 	ListT<Chain> atsList;
 	
-	pDBMng->getActiveTableSet(dbHost, atsList, true, false);
+	pDBMng->getActiveTableSet( atsList, true, false);
 	
 	if ( atsList.Size() > 0 )
 	{
-	    CegoDistManager tabMng(pDBMng);
+	    CegoQueryManager tabMng(pDBMng);
 	    Chain *pATS = atsList.First();
 	    while ( pATS )
 	    {	
@@ -1831,14 +1751,13 @@ int runDaemon(GetLongOpt& longOpt)
 	// finally sync the xml file to be safe
 	pDBMng->doc2Xml();
 	
-	// because admin threads are using dbthreadpool and logthread pool, we hove to terminate admin thread pool first
-#ifdef CGDEBUG	
-	pDBMng->log(modId, Logger::DEBUG, Chain("Deleting admin threadpool ..."));
-#endif
 
     }
     catch ( Exception e)
     {
+
+	// e.print();
+	
 	Chain msg;
 	Chain module;
 	unsigned line;
@@ -1878,17 +1797,14 @@ int runDaemon(GetLongOpt& longOpt)
     if ( pAdminPool )
     	delete pAdminPool;
 
-    if ( pLogPool )
-	delete pLogPool;
-
     if ( pDbPool )
 	delete pDbPool;
 
-    if ( pBeatThread )
-	delete pBeatThread;
+    if ( pSigCatch )
+	delete pSigCatch;
 
-    if ( pMedThread )
-	delete pMedThread;
+    if ( pArchThread )
+	delete pArchThread;
 
     if ( pLockHandler )
     {
@@ -2048,7 +1964,7 @@ int shiftActive(GetLongOpt& longOpt)
 	pDBMng->xml2Doc();
 	pDBMng->configureLogger();
 
-	CegoLogThreadPool::shiftActive(pDBMng, tableSet);
+	CegoArchiveThread::shiftActive(pDBMng, tableSet);
 		       	
 	pDBMng->doc2Xml();
 	
