@@ -27,7 +27,6 @@ const char *CEGO_MODULE_MAP[] =
 {
     "None",
     "CegoMain",
-    "CegoLogThread",
     "CegoDbThread",
     "CegoAction",
     "CegoDbHandler",
@@ -39,7 +38,6 @@ const char *CEGO_MODULE_MAP[] =
     "CegoSystemObject",
     "CegoBufferPool",
     "CegoLogManager",
-    "CegoLogHandler",
     "CegoAdminThread",
     "CegoObjectCursor",
     "CegoAVLIndexManager",
@@ -47,16 +45,14 @@ const char *CEGO_MODULE_MAP[] =
     "CegoExpOutStream",
     "CegoFileHandler",
     "CegoDatabaseManager",
-    "CegoMediatorThread",
-    "CegoDistManager",
+    "CegoArchiveThread",
+    "CegoQueryManager",
     "CegoRecoveryManager",
     "CegoDbThreadPool",
-    "CegoLogThreadPool",
     "CegoAdminThreadPool",
-    "CegoBeatThread",
-    "CegoBeatConnection",
-    "CegoDistDbHandler",
-    "CegoDistCursor",
+    "CegoSigCatch",
+    "CegoQueryHandler",
+    "CegoQueryCursor",
     "CegoAdminHandler",
     "CegoTransactionManager",
     "CegoLockHandler",
