@@ -1634,15 +1634,18 @@ CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, u
 			CegoDataPointer dp;
 			
 			PageIdType startPageId;
-			
-			if ( doAppend )			    
+
+			// cout << "Last Ref page id = " << oe.getRefLastDataPageId() << endl;
+			if (  doAppend ) 
 			{			
 			    startPageId = oe.getRefLastDataPageId();
+			    // cout << "Insert page data at append page " << startPageId << endl;
 			}
 			else
 			{
-			    startPageId = oe.getDataPageId();	       
-			}
+			    startPageId = oe.getDataPageId();
+			    // cout << "Insert page data at start page " << startPageId << endl;
+			}			
 			
 			bool isNewPage;
 			
@@ -2161,8 +2164,9 @@ CegoDataPointer CegoObjectManager::insertPageData(unsigned tabSetId, CegoObject:
 	{
 	    fixMode = CegoBufferPool::NOSYNC;
 	}
-	
-	unsigned long long cpCount = _pDBMng->getCPCount();
+
+	// diabled with version 2.53.5 
+	// unsigned long long cpCount = _pDBMng->getCPCount();
 	
 	_pDBMng->bufferFix(bp,
 			   tabSetId,
@@ -2190,17 +2194,22 @@ CegoDataPointer CegoObjectManager::insertPageData(unsigned tabSetId, CegoObject:
 		
 		_pDBMng->bufferUnfix(bp, true, _pLockHandle);
 
+		/* to check of this is still needed, from version 2.53.5, we have set LOGREC_SYCN to lsn = 0 */
 		/*
 		  if a checkpoint has occured before writing data to page, 
 		  we have to force checkpoint again, since the log entry is ignored.
 		  This is important in case of crash recovery.
 		*/
 
+		/*
 		if ( _pDBMng->getCPCount() > cpCount )
 		{
 		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Forced checkpoint by insertPageData"));
-		    _pDBMng->writeCheckPoint(tabSetId, true, Chain(), 0,  _pLockHandle);
-		}		
+		    unsigned long long lsn = _pDBMng->writeCheckPoint(tabSetId, true, Chain(), 0,  _pLockHandle);
+		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Forced checkpoint for insertPageData at ") + Chain(lsn));
+		}
+		*/
+		
 		return dp;	
 	    }
 	    else
