@@ -6,7 +6,7 @@
 //
 // Design and Implementation by Bjoern Lemke               
 //                                                         
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -53,7 +53,7 @@ bool CegoProcFetch::fetch()
     ListT<CegoField> fvl;
 
     bool moreTuple;
-    
+
     moreTuple = _pCur->nextTuple(fvl);
     
     if ( moreTuple )
@@ -67,17 +67,6 @@ bool CegoProcFetch::fetch()
 	    pVar = _varList.Next();
 	    pF = fvl.Next();
 	}
-
-	/*
-	CegoProcVar **pVar = _varList.First();
-	while ( pVar && pF )
-	{
-	    (*pVar)->setValue(pF->getValue());
-	    pVar = _varList.Next();
-	    pF = fvl.Next();
-	}
-	*/
-
     }
     
     return moreTuple;
