@@ -27,7 +27,7 @@
 #include <lfcbase/ListT.h>
 
 // cego includes
-#include "CegoDistManager.h"
+#include "CegoQueryManager.h"
 #include "CegoPredicate.h"
 #include "CegoExpr.h"
 #include "CegoAlterDesc.h"
@@ -54,12 +54,12 @@ public:
 
     enum TransactionOp { START, COMMIT, ROLLBACK };
 
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet, TransactionOp to);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet, TransactionOp to);
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      const Chain& tableAlias,
 	      CegoPredicate* pPred);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      const Chain& tableAlias,
 	      CegoPredicate* pPred,
@@ -67,23 +67,23 @@ public:
 	      const ListT<CegoExpr*>& updList,
 	      const ListT<CegoReturnVar*> retVarList,
 	      bool onFirst);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      bool doLock);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      const ListT<CegoField>& schema,
 	      const ListT<ListT<CegoExpr*> >& exprListArray);
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      const ListT<CegoField>& schema,
 	      CegoSelect* pSelect);
 
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& tableName,
 	      const ListT<CegoAlterDesc>& alterList);
     
-    CegoQuery(CegoDistManager* pGTM, const Chain& tableSet,
+    CegoQuery(CegoQueryManager* pGTM, const Chain& tableSet,
 	      const Chain& objName,
 	      CegoObject::ObjectType objType,
 	      const Chain& newObjName );    
@@ -101,7 +101,7 @@ private:
     void prepareFieldValue(CegoField *pFV, CegoFieldValue& fv, unsigned pos);
 
     QueryMode _mode;
-    CegoDistManager* _pGTM;
+    CegoQueryManager* _pGTM;
     Chain _tableName;
     Chain _tableAlias;
     Chain _objName;
