@@ -983,7 +983,7 @@ void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, Cego
     }
 }
 
-bool CegoQueryHelper::checkIndexForPredicate(unsigned tabSetId, CegoDistManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList)
+bool CegoQueryHelper::checkIndexForPredicate(unsigned tabSetId, CegoQueryManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList)
 {  
     CegoCondition* pC = pPred->getCondition();	
     if (pC)
@@ -1835,7 +1835,7 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 				   ListT<CegoExpr*>& exprList,
 				   bool& returnOnFirst,
 				   char* pBuf, unsigned buflen,
-				   CegoDistManager *pGTM, unsigned tabSetId)
+				   CegoQueryManager *pGTM, unsigned tabSetId)
 {
     unsigned aliasLen;
     memcpy(&aliasLen, pBuf, sizeof(unsigned));
@@ -1994,7 +1994,7 @@ void CegoQueryHelper::encodeDelRec(const Chain& tableAlias,
 void CegoQueryHelper::decodeDelRec(Chain& tableAlias,
 				   CegoPredicate* &pPred,
 				   char* pBuf, unsigned buflen,
-				   CegoDistManager *pGTM, unsigned tabSetId)
+				   CegoQueryManager *pGTM, unsigned tabSetId)
 {        
     unsigned aliasLen;
     memcpy(&aliasLen, pBuf, sizeof(unsigned));
