@@ -68,7 +68,7 @@ public:
     static void aggregateTuple(ListT<CegoField>& aggTuple, CegoAggregation* pAgg);
     // the given field value is checked for type information of the given field and casted if required 
     static void prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, CegoTableManager* pTM, unsigned tabSetId);
-    static bool checkIndexForPredicate(unsigned tabSetId, CegoDistManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList);
+    static bool checkIndexForPredicate(unsigned tabSetId, CegoQueryManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList);
     // field list encoding and decoding methods
     static void encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, unsigned &buflen);    
     static void decodeFL(ListT<CegoField>& fvl, char* pc, unsigned len);
@@ -86,7 +86,7 @@ public:
 			     ListT<CegoExpr*>& exprList,
 			     bool& returnOnFirst, 
 			     char* pBuf, unsigned buflen,
-			     CegoDistManager* pGTM, unsigned tabSetId); 
+			     CegoQueryManager* pGTM, unsigned tabSetId); 
     static void encodeUpdRec(const Chain& tableAlias,
 			     CegoPredicate* pPred, 
 			     const ListT<CegoField>& updList,
@@ -99,7 +99,7 @@ public:
     static void decodeDelRec(Chain& tableAlias,
 			     CegoPredicate* &pPred,
 			     char* pBuf, unsigned buflen,
-			     CegoDistManager *pGTM, unsigned tabSetId);
+			     CegoQueryManager *pGTM, unsigned tabSetId);
     static void encodeDelRec(const Chain& tableAlias,
 			     CegoPredicate* pPred,
 			     CegoProcBlock* pBlock,
