@@ -250,17 +250,23 @@ void CegoQueryManager::stopQueryTableSet(const Chain& tableSet, bool archComplet
 void CegoQueryManager::startQueryTableSet(const Chain& tableSet, bool cleanIt, bool cpDump, bool doAutoCorrect, bool doTempReset)
 {
     
-    _pDBMng->log(_modId, Logger::NOTICE, Chain("Starting tableset ") + tableSet + Chain(" ..."));
-    
-    _pDBMng->setCheckPointDump(tableSet, cpDump);
-    
-    // check, if we have a real problem
     Chain runState = _pDBMng->getTableSetRunState(tableSet);
+
     if ( runState == Chain(XML_CHECKPOINT_VALUE) )
     {
 	throw Exception(EXLOC, Chain("Checkpoint crash detected, tableset might be inconsistent")); 	
     }
 
+    if ( runState == Chain(XML_INCOMPLETE_VALUE) )
+    {
+	throw Exception(EXLOC, Chain("Incomplete tableset status detected, manual recovery needed")); 	
+    }
+
+    _pDBMng->log(_modId, Logger::NOTICE, Chain("Starting tableset ") + tableSet + Chain(" ..."));
+    
+    _pDBMng->setCheckPointDump(tableSet, cpDump);
+
+    
     Chain tsTicketName = _pDBMng->getTSTicket(tableSet);
     
     File tsTicket(tsTicketName);
