@@ -50,7 +50,7 @@ CegoReturnVar& CegoReturnVar::operator = ( const CegoReturnVar& rv)
     return (*this);
 }
 
-Chain CegoReturnVar::toChain(int defTabSetId) const
+Chain CegoReturnVar::toChain(unsigned defTabSetId) const
 {
     Chain s;
     s = Chain(":")  + _varName + " = " + _pExpr->toChain(defTabSetId);
