@@ -36,7 +36,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoSelect::CegoSelect(char* buf, CegoQueryManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pPred = 0;
     _pNativeOrderList = 0;
@@ -103,7 +103,7 @@ CegoSelect::CegoSelect(ListT<CegoContentObject*>& coList,
 		       ListT<CegoOrderNode::Ordering>* pOrderOptList,
 		       bool isDistinct,
 		       unsigned rowLimit,
-		       CegoDistManager* pGTM)
+		       CegoQueryManager* pGTM)
 {
     _coList = coList;
     _exprList = exprList;
@@ -288,7 +288,7 @@ CegoSelect::~CegoSelect()
 	delete _pCacheList;
 }
 
-void CegoSelect::setTableManager(CegoDistManager* pGTM)
+void CegoSelect::setTableManager(CegoQueryManager* pGTM)
 {
     _pGTM = pGTM;
     if ( _pGTM )
@@ -700,7 +700,7 @@ Element* CegoSelect::getPlan()
 #endif	
     
 	_pTC[_joinLevel] = 
-	    new CegoDistCursor(_pGTM, _joinList[_joinLevel], _pBlock);
+	    new CegoQueryCursor(_pGTM, _joinList[_joinLevel], _pBlock);
 	
 	if ( _attrCondFlag[_joinLevel] == true )
 	{
@@ -725,11 +725,11 @@ Element* CegoSelect::getPlan()
 		}
 	    }
 	    if ( _pParentJoinBuf == 0 )
-		_pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
+		_pTC[_joinLevel]->querySetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
 	    else
 	    {
 		mergeBuffer();
-		_pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
+		_pTC[_joinLevel]->querySetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
 	    }
 		
 	}
@@ -743,11 +743,11 @@ Element* CegoSelect::getPlan()
 	    // since cursor predicate may contain parent references, we just up, if parent join buf is empty
 
 	    if ( _pParentJoinBuf == 0 )
-		_pTC[_joinLevel]->distSetup(_joinBuf, _cursorPred[_joinLevel]);
+		_pTC[_joinLevel]->querySetup(_joinBuf, _cursorPred[_joinLevel]);
 	    else
 	    {
 		mergeBuffer();
-		_pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+		_pTC[_joinLevel]->querySetup(_pMergedBuf, _cursorPred[_joinLevel]);
 	    }
 
 	}
@@ -1764,7 +1764,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 
 		    
 		    _pTC[_joinLevel] = 
-			new CegoDistCursor(_pGTM, _joinList[_joinLevel], _pBlock);
+			new CegoQueryCursor(_pGTM, _joinList[_joinLevel], _pBlock);
 		}
 		else
 		{
@@ -1783,11 +1783,11 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 #endif
 
 			if ( _pParentJoinBuf == 0 )
-			    _pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
+			    _pTC[_joinLevel]->querySetup(_attrCond[_joinLevel], _joinBuf, _cursorPred[_joinLevel]);
 			else
 			{
 			    mergeBuffer();
-			    _pTC[_joinLevel]->distSetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
+			    _pTC[_joinLevel]->querySetup(_attrCond[_joinLevel], _pMergedBuf, _cursorPred[_joinLevel]);
 			}
 		    }	 
 		    else
@@ -1803,11 +1803,11 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 
 			// since cursor predicate may contain parent references, we just up, if parent join buf is empty
 			if ( _pParentJoinBuf == 0 )
-			    _pTC[_joinLevel]->distSetup(_joinBuf, _cursorPred[_joinLevel]);
+			    _pTC[_joinLevel]->querySetup(_joinBuf, _cursorPred[_joinLevel]);
 			else
 			{
 			    mergeBuffer();
-			    _pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+			    _pTC[_joinLevel]->querySetup(_pMergedBuf, _cursorPred[_joinLevel]);
 			}
 
 		    }		    
@@ -1816,12 +1816,12 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		{
 		    if ( _pParentJoinBuf == 0 )
 		    {
-			_pTC[_joinLevel]->distSetup(_joinBuf,  _cursorPred[_joinLevel]);
+			_pTC[_joinLevel]->querySetup(_joinBuf,  _cursorPred[_joinLevel]);
 		    }
 		    else
 		    {
 			mergeBuffer();
-			_pTC[_joinLevel]->distSetup(_pMergedBuf, _cursorPred[_joinLevel]);
+			_pTC[_joinLevel]->querySetup(_pMergedBuf, _cursorPred[_joinLevel]);
 		    }
 		}
 
@@ -3503,7 +3503,7 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoSelect::decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pBuf = (char*)buf;
     
