@@ -35,7 +35,7 @@ CegoTableCache::TableCacheEntry::TableCacheEntry()
     _numUsed=0;
 }
 
-CegoTableCache::TableCacheEntry::TableCacheEntry(int tabSetId, const Chain& tableName)
+CegoTableCache::TableCacheEntry::TableCacheEntry(unsigned tabSetId, const Chain& tableName)
 {
     _tabSetId = tabSetId;
     _tableName = tableName;
@@ -46,7 +46,7 @@ CegoTableCache::TableCacheEntry::TableCacheEntry(int tabSetId, const Chain& tabl
     _numUsed=0;
 }
 
-CegoTableCache::TableCacheEntry::TableCacheEntry(int tabSetId, const Chain& tableName, ListT< ListT<CegoFieldValue> >* pCacheList)
+CegoTableCache::TableCacheEntry::TableCacheEntry(unsigned tabSetId, const Chain& tableName, ListT< ListT<CegoFieldValue> >* pCacheList)
 {
     _tabSetId = tabSetId;
     _tableName = tableName;
@@ -60,7 +60,7 @@ CegoTableCache::TableCacheEntry::TableCacheEntry(int tabSetId, const Chain& tabl
     {
 	CegoFieldValue** pCFVL = new CegoFieldValue*[pFVL->Size()];
 	CegoFieldValue* pFV = pFVL->First();
-	int i = 0;
+	unsigned i = 0;
 	while ( pFV )
 	{
 	    CegoFieldValue* pCFV = new CegoFieldValue(pFV->getLocalCopy());
@@ -81,14 +81,14 @@ CegoTableCache::TableCacheEntry::~TableCacheEntry()
 {
 }
 
-const int CegoTableCache::TableCacheEntry::getSize() const
+const unsigned CegoTableCache::TableCacheEntry::getSize() const
 {
-    int s = sizeof(int); // tabsSetId
+    unsigned s = sizeof(unsigned); // tabsSetId
     s += _tableName.length();
 
-    for ( int i=0; i<_numRow; i++ )
+    for ( unsigned i=0; i<_numRow; i++ )
     {
-	for ( int j=0; j<_numCol; j++ )
+	for ( unsigned j=0; j<_numCol; j++ )
 	{
 	    CegoFieldValue *pF = _pCacheArray[i][j];
 	    s += pF->size();
@@ -97,17 +97,17 @@ const int CegoTableCache::TableCacheEntry::getSize() const
     return s;	
 }
 
-int CegoTableCache::TableCacheEntry::getHashPos(int hashSize) const
+unsigned CegoTableCache::TableCacheEntry::getHashPos(unsigned hashSize) const
 {
     return _tableName.getHashPos(hashSize);
 }
 
-int CegoTableCache::TableCacheEntry::getNumRows() const
+unsigned CegoTableCache::TableCacheEntry::getNumRows() const
 {
     return _numRow;
 }
 
-int CegoTableCache::TableCacheEntry::getNumCols() const
+unsigned CegoTableCache::TableCacheEntry::getNumCols() const
 {
     return _numCol;
 }
@@ -117,7 +117,7 @@ const Chain& CegoTableCache::TableCacheEntry::getTableName() const
     return _tableName;
 }
 
-int CegoTableCache::TableCacheEntry::getTabSetId() const
+unsigned CegoTableCache::TableCacheEntry::getTabSetId() const
 {
     return _tabSetId;
 }
@@ -148,9 +148,9 @@ bool CegoTableCache::TableCacheEntry::cleanCache()
     if ( _numUsed > 0 )
 	return false;
     
-    for ( int i=0; i<_numRow; i++ )
+    for ( unsigned i=0; i<_numRow; i++ )
     {
-	for ( int j=0; j<_numCol; j++ )
+	for ( unsigned j=0; j<_numCol; j++ )
 	    delete _pCacheArray[i][j];
 	delete _pCacheArray[i];
     }
@@ -177,7 +177,7 @@ bool CegoTableCache::TableCacheEntry::operator == ( const CegoTableCache::TableC
     return false;
 }
 
-CegoTableCache::CegoTableCache(int tabSetId, const Chain& cacheFilter, int maxSize, int maxEntry, int hashRange, CegoDatabaseManager* pDBMng)
+CegoTableCache::CegoTableCache(unsigned tabSetId, const Chain& cacheFilter, unsigned maxSize, unsigned maxEntry, unsigned hashRange, CegoDatabaseManager* pDBMng)
 {
     _cacheLock[tabSetId].init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
     _cacheLock[tabSetId].setId( Chain("TCACHE") + Chain("-") + Chain(tabSetId));
@@ -249,7 +249,7 @@ Element* CegoTableCache::getCacheInfo()
     pN->setAttribute(XML_VALUE_ATTR, Chain(_usedSize));
     pCacheInfo->addContent(pN);
 
-    int numEntry = _pTableCache->numEntry();
+    unsigned numEntry = _pTableCache->numEntry();
     pN = new Element(XML_CACHE_ELEMENT);
     pN->setAttribute(XML_ATTRNAME_ATTR, Chain("NumEntry"));
     pN->setAttribute(XML_VALUE_ATTR, Chain(numEntry));
@@ -298,22 +298,22 @@ void CegoTableCache::setFilter(const Chain& cacheFilter)
     _cacheFilter = cacheFilter;
 }
 
-int CegoTableCache::getMaxSize() const
+unsigned CegoTableCache::getMaxSize() const
 {
     return _maxSize;
 }
 
-void CegoTableCache::setMaxSize(int maxSize)
+void CegoTableCache::setMaxSize(unsigned maxSize)
 {
     _maxSize = maxSize;
 }
 
-int CegoTableCache::getUsedSize() const
+unsigned CegoTableCache::getUsedSize() const
 {
     return _usedSize;
 }
 
-const int CegoTableCache::getNumTableCache() const
+const unsigned CegoTableCache::getNumTableCache() const
 {
     return _pTableCache->Size();
 }
@@ -333,7 +333,7 @@ void CegoTableCache::invalidate(const Chain& tableName)
 	{
 	    if ( pTCE->getTabSetId() == _tabSetId && pTCE->getTableName() == tableName )
 	    {
-		int s = pTCE->getSize();
+		unsigned s = pTCE->getSize();
 		if  ( pTCE->cleanCache() )
 		{
 		    _usedSize = _usedSize - s;
@@ -358,7 +358,7 @@ void CegoTableCache::invalidate(const Chain& tableName)
     }
 }
 
-CegoFieldValue*** CegoTableCache::claimEntry(const Chain& tableName, int& numRow, int& numCol)
+CegoFieldValue*** CegoTableCache::claimEntry(const Chain& tableName, unsigned& numRow, unsigned& numCol)
 {    
     CegoFieldValue*** pCE = 0;
     PR();
@@ -399,8 +399,8 @@ bool CegoTableCache::addEntry(const Chain& tableName, ListT< ListT<CegoFieldValu
     {
 	bool wasInserted = false;
 	
-	int tryDelay = TABLECACHE_TRYDELAYBASE;
-	int tryCount = 0;
+	unsigned tryDelay = TABLECACHE_TRYDELAYBASE;
+	unsigned tryCount = 0;
 	
 	while ( wasInserted == false && tryCount < TABLECACHE_MAXTRY)
 	{
@@ -427,7 +427,7 @@ bool CegoTableCache::addEntry(const Chain& tableName, ListT< ListT<CegoFieldValu
 		{
 		    TableCacheEntry *pRE = 0;
 		    
-		    int pos;
+		    unsigned pos;
 		    unsigned long minHit = 0;
 		    TableCacheEntry *pTCE = _pTableCache->FirstInRange(tce);
 		    while ( pTCE )
@@ -444,7 +444,7 @@ bool CegoTableCache::addEntry(const Chain& tableName, ListT< ListT<CegoFieldValu
 		    
 		    if ( pRE )
 		    {
-			int s = pRE->getSize();
+			unsigned s = pRE->getSize();
 			if ( pRE->cleanCache() )
 			{
 			    _usedSize = _usedSize - s;
@@ -527,7 +527,7 @@ void CegoTableCache::clean()
     _usedSize = 0;
 }
 
-void CegoTableCache::getTCLockStat(int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoTableCache::getTCLockStat(unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockCount = _cacheLock[_tabSetId].numLockTry();
     
