@@ -41,7 +41,7 @@ class CegoTableCursor {
 public:
     
     CegoTableCursor();
-    CegoTableCursor(CegoTableManager* pTM, int tabSetId, const Chain& tableName, bool ignoreTouched = false);
+    CegoTableCursor(CegoTableManager* pTM, unsigned tabSetId, const Chain& tableName, bool ignoreTouched = false);
     ~CegoTableCursor();
     
     CegoAttrCond::IndexMatch setup(const CegoAttrCond& attrCond);
@@ -75,7 +75,7 @@ private:
     Chain _idxName;
     CegoObject::ObjectType _type;
     CegoAttrCond::IndexMatch _idxMatch;
-    int _tabSetId;
+    unsigned _tabSetId;
     bool _ignoreTouched;
     bool _readUncommitted;
     bool _idxCached;
