@@ -124,17 +124,17 @@ CegoTransactionManager::~CegoTransactionManager()
 {
 }
 
-void CegoTransactionManager::release(int tabSetId)
+void CegoTransactionManager::release(unsigned tabSetId)
 {
     // nothing to do anymore
 }
 
-void CegoTransactionManager::reorgSystemSpace(int tabSetId)
+void CegoTransactionManager::reorgSystemSpace(unsigned tabSetId)
 {
     // nothing to do anymore
 }
 
-void CegoTransactionManager::newRBEntry(int tabSetId, unsigned long long tid, PageIdType pageId, int offset, const Chain& tableName)
+void CegoTransactionManager::newRBEntry(unsigned tabSetId, unsigned long long tid, PageIdType pageId, unsigned offset, const Chain& tableName)
 {
     TAEntry *pTAE = _taList.Find( TAEntry(tid));
 
@@ -182,9 +182,9 @@ void CegoTransactionManager::newRBEntry(int tabSetId, unsigned long long tid, Pa
     CegoTupleState ts = COMMITTED;
     
     char *pBufBase = 0;
-    int buflen = 0;
+    unsigned buflen = 0;
     
-    int encLen = _qh.encodeFVL(rbtid, rbtastep, ts, fl, pBufBase, buflen);
+    unsigned encLen = _qh.encodeFVL(rbtid, rbtastep, ts, fl, pBufBase, buflen);
     
     try
     {	
@@ -202,7 +202,7 @@ void CegoTransactionManager::newRBEntry(int tabSetId, unsigned long long tid, Pa
    For crash recovery, we have to find out about all affected tables
 */
 
-void CegoTransactionManager::getCrashAffectedTables(int tabSetId, SetT<Chain>& tableList)
+void CegoTransactionManager::getCrashAffectedTables(unsigned tabSetId, SetT<Chain>& tableList)
 {
     CegoObjectCursor *pOC = 0;
     
@@ -264,7 +264,7 @@ void CegoTransactionManager::getCrashAffectedTables(int tabSetId, SetT<Chain>& t
    a possible deadlock
 */
 
-void CegoTransactionManager::getTransactionAffectedTables(int tabSetId, unsigned long long tid, SetT<Chain>& tableList)
+void CegoTransactionManager::getTransactionAffectedTables(unsigned tabSetId, unsigned long long tid, SetT<Chain>& tableList)
 {
     CegoObjectCursor *pOC = 0;
 
@@ -312,7 +312,7 @@ void CegoTransactionManager::getTransactionAffectedTables(int tabSetId, unsigned
     }
 }
 
-bool CegoTransactionManager::hasOpenTransaction(int tabSetId, const Chain& tableName) const
+bool CegoTransactionManager::hasOpenTransaction(unsigned tabSetId, const Chain& tableName) const
 {
     ListT<Chain> rboList;    
 
@@ -354,7 +354,7 @@ bool CegoTransactionManager::hasOpenTransaction(int tabSetId, const Chain& table
     return tabFound;
 }
 	
-void CegoTransactionManager::finishOpenTransaction(int tabSetId)
+void CegoTransactionManager::finishOpenTransaction(unsigned tabSetId)
 {
     Chain tableSet = _pDBMng->getTabSetName(tabSetId);
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Finishing open transaction for tableset ") + tableSet);
@@ -375,7 +375,7 @@ void CegoTransactionManager::finishOpenTransaction(int tabSetId)
 
 	_pDBMng->log(_modId, Logger::NOTICE, Chain("Treating ") + *pRBO + Chain(" Tid = ") + taTid + Chain(" Type = ") + taType);
 		     
-	int tid = taTid.asInteger();
+	unsigned tid = taTid.asUnsigned();
 	
 	if ( taType == Chain(SYS_RB) )
 	{	    
@@ -406,7 +406,7 @@ void CegoTransactionManager::finishOpenTransaction(int tabSetId)
     }    
 }
 
-unsigned long long CegoTransactionManager::commitTransaction(int tabSetId, unsigned long long tid)
+unsigned long long CegoTransactionManager::commitTransaction(unsigned tabSetId, unsigned long long tid)
 {   
     unsigned long long opCount = 0;
 
@@ -457,7 +457,7 @@ unsigned long long CegoTransactionManager::commitTransaction(int tabSetId, unsig
     return opCount;
 }
 
-unsigned long long CegoTransactionManager::rollbackTransaction(int tabSetId, unsigned long long tid)
+unsigned long long CegoTransactionManager::rollbackTransaction(unsigned tabSetId, unsigned long long tid)
 {    
     unsigned long long opCount = 0;
 
@@ -503,7 +503,7 @@ unsigned long long CegoTransactionManager::rollbackTransaction(int tabSetId, uns
     return opCount;    
 }
 
-unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& rbo)
+unsigned long long CegoTransactionManager::doCommit(unsigned tabSetId, const Chain& rbo)
 {
     unsigned long long opCount = 0;
 
@@ -527,12 +527,12 @@ unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& r
 	ListT<CegoTriggerObject> cachedTriggerList;
 	ListT<CegoAliasObject> cachedAliasList;
 	
-	int numInvalid;
+	unsigned numInvalid;
 
 	while (moreTuple)
 	{
 	    PageIdType pageId;
-	    int offset;
+	    unsigned offset;
 
 	    CegoField *pF = schema.Find(CegoField(SYS_RB, SYS_RB_PAGEID));
 	    if (pF)
@@ -548,7 +548,7 @@ unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& r
 	    pF = schema.Find(CegoField(SYS_RB, SYS_RB_OFFSET));
 	    if (pF)
 	    {
-		memcpy(&offset, pF->getValue().getValue(), sizeof(int));
+		memcpy(&offset, pF->getValue().getValue(), sizeof(unsigned));
 	    }
 	    else
 	    {
@@ -590,7 +590,7 @@ unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& r
 		}
 		
 		char* p;
-		int len;
+		unsigned len;
 
 		CegoBufferPage bp;
 		
@@ -598,10 +598,10 @@ unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& r
 		{
 		    _pTabMng->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, bp);
 
-		    int toff = _qh.skipTupleHeader();
+		    unsigned toff = _qh.skipTupleHeader();
 
 		    char* tp = p + toff;
-		    int tlen = len - toff;
+		    unsigned tlen = len - toff;
 		   
 		    _qh.decodeFVL(cachedFvl, tp, tlen);
 
@@ -650,7 +650,7 @@ unsigned long long CegoTransactionManager::doCommit(int tabSetId, const Chain& r
     return opCount;
 }
 
-unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain& rbo)
+unsigned long long CegoTransactionManager::doRollback(unsigned tabSetId, const Chain& rbo)
 {
     unsigned long long opCount = 0;
     unsigned long long recLock = 0;
@@ -676,12 +676,12 @@ unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain&
 	ListT<CegoTriggerObject> cachedTriggerList;
 	ListT<CegoAliasObject> cachedAliasList;
 	
-	int numInvalid;
+	unsigned numInvalid;
 
 	while (moreTuple)
 	{
 	    PageIdType pageId;
-	    int offset;
+	    unsigned offset;
 	    Chain tableName;
 	    
 	    CegoField *pF = schema.Find(CegoField(SYS_RB, SYS_RB_PAGEID));
@@ -698,7 +698,7 @@ unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain&
 	    pF = schema.Find(CegoField(SYS_RB, SYS_RB_OFFSET));
 	    if (pF)
 	    {
-		memcpy(&offset, pF->getValue().getValue(), sizeof(int));
+		memcpy(&offset, pF->getValue().getValue(), sizeof(unsigned));
 	    }
 	    else
 	    {
@@ -752,7 +752,7 @@ unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain&
 		}
 		
 		char* p;
-		int len;
+		unsigned len;
 
 		CegoBufferPage bp;
 		
@@ -760,10 +760,10 @@ unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain&
 		{
 		    _pTabMng->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, bp);
 		    
-		    int toff = _qh.skipTupleHeader();
+		    unsigned toff = _qh.skipTupleHeader();
 
 		    char* tp = p + toff;
-		    int tlen = len - toff;
+		    unsigned tlen = len - toff;
 		    
 		    _qh.decodeFVL(cachedFvl, tp, tlen);
 
@@ -806,7 +806,7 @@ unsigned long long CegoTransactionManager::doRollback(int tabSetId, const Chain&
     return opCount;
 }
 
-void CegoTransactionManager::getTransactionInfo(int tabSetId, const Chain& rbo, int& numop)
+void CegoTransactionManager::getTransactionInfo(unsigned tabSetId, const Chain& rbo, unsigned& numop)
 {    
     CegoObjectCursor *pOC;
 
@@ -842,7 +842,7 @@ void CegoTransactionManager::getTransactionInfo(int tabSetId, const Chain& rbo,
     }
 }
 
-void CegoTransactionManager::recordUpdate(int tabSetId, unsigned long long tid, const CegoDataPointer& dp )
+void CegoTransactionManager::recordUpdate(unsigned tabSetId, unsigned long long tid, const CegoDataPointer& dp )
 {
     TAEntry *pUDE = _udList.Find( TAEntry(tid));
     
@@ -864,7 +864,9 @@ void CegoTransactionManager::recordUpdate(int tabSetId, unsigned long long tid,
     }
 
     PageIdType pageId = dp.getPageId();
-    int offset = dp.getOffset();
+
+    // we use type int here to satisfy CegoFieldValue INT_TYPE
+    int offset = (int)dp.getOffset();
 
     CegoFieldValue fv1(PAGEID_TYPE, &pageId, sizeof(PageIdType));
     CegoField f1(CegoField(SYS_UPDTAB, SYS_UPDTAB, SYS_UPDTAB_PAGEID, PAGEID_TYPE, sizeof(PageIdType), 0, fv1, true, 1));	
@@ -881,11 +883,11 @@ void CegoTransactionManager::recordUpdate(int tabSetId, unsigned long long tid,
     CegoTupleState ts = COMMITTED;
 
     char *pBufBase = 0;
-    int buflen = 0;
+    unsigned buflen = 0;
 
     try
     {
-	int encLen = _qh.encodeFVL(rbtid, rbtastep, ts, fl, pBufBase, buflen);    	
+	unsigned encLen = _qh.encodeFVL(rbtid, rbtastep, ts, fl, pBufBase, buflen);    	
 	CegoDataPointer dp = _pTabMng->insertData(pUDE->getTableObject(), pBufBase, encLen, true);
     }
     catch ( Exception e )
@@ -904,7 +906,7 @@ void CegoTransactionManager::recordUpdate(int tabSetId, unsigned long long tid,
    In this case, the ( virgin ) index still has to expand for the updated tuples
 */
 
-void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, const CegoObject::ObjectType idxType, unsigned long long tid, bool doAppend)
+void CegoTransactionManager::commitUpdate(unsigned tabSetId, const Chain& idxName, const CegoObject::ObjectType idxType, unsigned long long tid, bool doAppend)
 {
     CegoObjectCursor *pOC = 0;
     CegoBufferPage bp;
@@ -942,6 +944,8 @@ void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, co
 	    while ( moreTuple)
 	    {
 		PageIdType pageId;
+
+		// we leave offset as int to satisfy CegoFieldValue INT type
 		int offset;
 		
 		CegoField *pF = schema.Find(CegoField(SYS_UPDTAB, SYS_UPDTAB_PAGEID));
@@ -966,27 +970,27 @@ void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, co
 		    throw Exception(EXLOC, msg);
 		}
 
-		CegoDataPointer dp(pageId, offset);
+		CegoDataPointer dp(pageId, (unsigned)offset);
 		
 		ListT<CegoField> fvl = ioe.getSchema();
 		
 		char* p;
-		int len;
+		unsigned len;
 		
 		CegoDataPointer sysEntry(bp.getPageId(), bp.getEntryPos());
 				
 		_pTabMng->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, cbp);
 	      		
-		int toff = _qh.skipTupleHeader();
+		unsigned toff = _qh.skipTupleHeader();
 
 		char* tp = p + toff;
-		int tlen = len - toff;
+		unsigned tlen = len - toff;
 
 		_qh.decodeFVL(fvl, tp, tlen);
 		
 		char ip[TABMNG_MAXINDEXVALUE];
-		int ilen = TABMNG_MAXINDEXVALUE;
-		int idxLen;
+		unsigned ilen = TABMNG_MAXINDEXVALUE;
+		unsigned idxLen;
 		CegoDataPointer ritp;
 		
 		_pTabMng->extractIndexValue(fvl, ioe.getSchema(), ip, ilen, idxLen);
@@ -1036,6 +1040,7 @@ void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, co
 	    while ( moreTuple)
 	    {
 		PageIdType pageId;
+		// we leave offset as int to satisfy CegoFieldValue INT type
 		int offset;
 		
 		CegoField *pF = schema.Find(CegoField(SYS_UPDTAB, SYS_UPDTAB_PAGEID));
@@ -1060,19 +1065,19 @@ void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, co
 		    throw Exception(EXLOC, msg);
 		}
 
-		CegoDataPointer dp(pageId, offset);
+		CegoDataPointer dp(pageId, (unsigned)offset);
 		
 		ListT<CegoField> fvl = boe.getSchema();
 		
 		char* p;
-		int len;	       
+		unsigned len;	       
 		
 		_pTabMng->claimDataPtrUnlocked(tabSetId, CegoBufferPool::SYNC, dp, p, len, cbp);
 
-		int toff = _qh.skipTupleHeader();
+		unsigned toff = _qh.skipTupleHeader();
 
 		char* tp = p + toff;
-		int tlen = len - toff;
+		unsigned tlen = len - toff;
 
 		_qh.decodeFVL(fvl, tp, tlen);
 
@@ -1129,7 +1134,7 @@ void CegoTransactionManager::commitUpdate(int tabSetId, const Chain& idxName, co
     }
 }
 
-void CegoTransactionManager::abortUpdate(int tabSetId, unsigned long long tid)
+void CegoTransactionManager::abortUpdate(unsigned tabSetId, unsigned long long tid)
 {    
     TAEntry *pUDE = _udList.Find( TAEntry(tid) );
     
