@@ -36,11 +36,11 @@ CegoTriggerObject::CegoTriggerObject(const CegoTriggerObject& to) : CegoDecodabl
     _triggerText = to._triggerText;
 }
 
-CegoTriggerObject::CegoTriggerObject(ObjectType type, const Chain& objName, int tabSetId) : CegoDecodableObject(type, objName, tabSetId)
+CegoTriggerObject::CegoTriggerObject(ObjectType type, const Chain& objName, unsigned tabSetId) : CegoDecodableObject(type, objName, tabSetId)
 {
 }
 
-CegoTriggerObject::CegoTriggerObject(int tabSetId,
+CegoTriggerObject::CegoTriggerObject(unsigned tabSetId,
 				     const Chain& triggerName,
 				     bool isBefore,
 				     bool isOnInsert,
@@ -120,9 +120,9 @@ const Chain& CegoTriggerObject::getTriggerText() const
     return _triggerText;
 }
 
-int CegoTriggerObject::getEntrySize() const
+unsigned CegoTriggerObject::getEntrySize() const
 {
-    int entrySize = CegoObject::getBaseSize();
+    unsigned entrySize = CegoObject::getBaseSize();
 
     entrySize += 4; // isBefore + isOnInsert + isOnUpdate + isOnDelete
     entrySize += 1; // object tabname size
@@ -137,7 +137,7 @@ void CegoTriggerObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
 
     CegoObject::encodeBase(bufPtr, entrySize);
     bufPtr += CegoObject::getBaseSize();
@@ -174,7 +174,7 @@ void CegoTriggerObject::decode(char *buf)
 {
     char* bufPtr = buf;
 
-    int size;
+    unsigned size;
 
     CegoObject::decodeBase(bufPtr, size);
     bufPtr += CegoObject::getBaseSize();
