@@ -31,7 +31,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoXPorter::CegoXPorter(CegoDistManager* pGTM, CegoAdminHandler* pAH)
+CegoXPorter::CegoXPorter(CegoQueryManager* pGTM, CegoAdminHandler* pAH)
 {
     _pGTM = pGTM;
     _pDBMng = pGTM->getDBMng();
@@ -190,7 +190,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		    pCol = colList.Next();
 		}		
 		
-		_pGTM->createDistIndexTable(tableSet, idxName, tabName, fl, idxType);
+		_pGTM->createQueryIndex(tableSet, idxName, tabName, fl, idxType);
 	    }
 	    
 	    pIdxElement = idxList.Next();
@@ -247,7 +247,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		}
 	    }
 	    
-	    _pGTM->createDistForeignKey(tableSet, fkey, tableName, keyList, refTable, refList);
+	    _pGTM->createQueryForeignKey(tableSet, fkey, tableName, keyList, refTable, refList);
 	    
 	    pFKeyElement = fkeyList.Next();
 	}
@@ -293,7 +293,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		pPred = new CegoPredicate(pCond);
 	    }
 	    
-	    _pGTM->createDistCheck(tableSet, checkName, tableName, pPred);
+	    _pGTM->createQueryCheck(tableSet, checkName, tableName, pPred);
 	    	    
 	    pCheckElement = checkList.Next();
 	}
@@ -341,7 +341,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		_pAH->sendInfo(info + Chain("\n"));
 	    _pDBMng->log(_modId, Logger::NOTICE, info);
 	    	    	    
-	    _pGTM->createDistTrigger(tableSet, triggerName,
+	    _pGTM->createQueryTrigger(tableSet, triggerName,
 				     isBefore, isOnInsert, isOnUpdate, isOnDelete,
 				     tableName, triggerText);
 
@@ -374,7 +374,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		pCol = colList.Next();
 	    }
 
-	    _pGTM->createDistAlias(tableSet, aliasName,
+	    _pGTM->createQueryAlias(tableSet, aliasName,
 				   tableName, aliasAttrList); 	    	   
 	    
 	    pAliasElement = aliasList.Next();
@@ -457,7 +457,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		    pCol = colList.Next();
 		}
 		
-		_pGTM->createDistView(tableSet, viewName, fl, viewStmt);				
+		_pGTM->createQueryView(tableSet, viewName, fl, viewStmt);				
 	    }
 	    
 	    pViewElement = viewList.Next();
@@ -477,7 +477,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		_pAH->sendInfo(info + Chain("\n"));
 	    _pDBMng->log(_modId, Logger::NOTICE, info);
 	    
-	    _pGTM->createDistProc(tableSet, procName, procText);
+	    _pGTM->createQueryProc(tableSet, procName, procText);
 	    
 	    pProcElement = procList.Next();
 	}
@@ -639,7 +639,7 @@ void CegoXPorter::xmlExportTableSet(const Chain& tableSet, bool isStructure, con
 	    
 	    CegoTableObject toe;
 	    // we use the method from CegoDistManager to verify user access
-	    _pGTM->getDistObject(tableSet, *pTab, CegoObject::TABLE, toe);
+	    _pGTM->getObject(tabSetId, *pTab, CegoObject::TABLE, toe);
 	    
 	    ListT<CegoField> schema = toe.getSchema();
 	    
@@ -1340,7 +1340,7 @@ void CegoXPorter::binExportTableSet(const Chain& tableSet, bool isStructure, con
 	    	    
 	    CegoTableObject toe;
 	    // we use the method from CegoDistManager to verify user access
-	    _pGTM->getDistObject(tableSet, *pTab, CegoObject::TABLE, toe);
+	    _pGTM->getObject(tabSetId, *pTab, CegoObject::TABLE, toe);
 	    	    
 	    writeTableObject(pOutFile, tabSetId, *pTab, toe.getSchema(), doPlain);
 	    
@@ -2184,7 +2184,7 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
     }
 
     ListT<CegoField> idxList;
-    _pGTM->createDistDataTable(tableSet, tableName, CegoObject::TABLE, schema, idxList, true);
+    _pGTM->createQueryTable(tableSet, tableName, schema, idxList, true);
     
     unsigned long long rowCount = 0;
 
@@ -2319,7 +2319,7 @@ void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
     
-    _pGTM->createDistIndexTable(tableSet, idxName, tableName, schema, type);
+    _pGTM->createQueryIndex(tableSet, idxName, tableName, schema, type);
 }
 
 void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
@@ -2397,7 +2397,7 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistForeignKey(tableSet, keyName, tableName, keySchema, refTable, refSchema);    
+    _pGTM->createQueryForeignKey(tableSet, keyName, tableName, keySchema, refTable, refSchema);    
 }
 
 void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
@@ -2438,7 +2438,7 @@ void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistCheck(tableSet, checkName, tableName, pPredDesc);    
+    _pGTM->createQueryCheck(tableSet, checkName, tableName, pPredDesc);    
 }
 
 void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
@@ -2510,7 +2510,7 @@ void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistTrigger(tableSet, triggerName,
+    _pGTM->createQueryTrigger(tableSet, triggerName,
 			     isBefore, isOnInsert, isOnUpdate, isOnDelete,
 			     tableName, triggerText);    
 }
@@ -2568,7 +2568,7 @@ void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistAlias(tableSet, aliasName,
+    _pGTM->createQueryAlias(tableSet, aliasName,
 			   tableName, aliasList);
 }
 
@@ -2633,7 +2633,7 @@ void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistView(tableSet, viewName, viewSchema, viewStmt);   
+    _pGTM->createQueryView(tableSet, viewName, viewSchema, viewStmt);   
 }
 
 void CegoXPorter::readProcObject(File *pInFile, const Chain& tableSet)
@@ -2661,7 +2661,7 @@ void CegoXPorter::readProcObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    _pGTM->createDistProc(tableSet, procName, procText);
+    _pGTM->createQueryProc(tableSet, procName, procText);
 
     pInFile->readByte((char*)&_tag, sizeof(BinTag));
 }
